from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class rvc_v2(FastClient):
    """
    Generated client for pseudoram/rvc-v2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ceaa8915-7b34-4775-b445-bf769fe8c5a2", api_key=api_key)
    
    def predictions(self, protect: float = 0.33, f0_method: str = 'rmvpe', rvc_model: str = 'Obama', index_rate: float = 0.5, pitch_change: float = 0.0, rms_mix_rate: float = 0.25, filter_radius: int = 3, output_format: str = 'mp3', crepe_hop_length: int = 128, input_audio: Optional[Union[MediaFile, str, bytes]] = None, custom_rvc_model_download_url: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            protect: Control how much of the original vocals' breath and voiceless consonants to leave in the AI vocals. Set 0.5 to disable. Defaults to 0.33.
            
            f0_method: Pitch detection algorithm. 'rmvpe' for clarity in vocals, 'mangio-crepe' for smoother vocals. Defaults to 'rmvpe'.
            
            rvc_model: RVC model for a specific voice. If using a custom model, this should match the name of the downloaded model. If a 'custom_rvc_model_download_url' is provided, this will be automatically set to the name of the downloaded model. Defaults to 'Obama'.
            
            index_rate: Control how much of the AI's accent to leave in the vocals. Defaults to 0.5.
            
            pitch_change: Adjust pitch of AI vocals in semitones. Use positive values to increase pitch, negative to decrease. Defaults to 0.0.
            
            rms_mix_rate: Control how much to use the original vocal's loudness (0) or a fixed loudness (1). Defaults to 0.25.
            
            filter_radius: If >=3: apply median filtering to the harvested pitch results. Defaults to 3.
            
            output_format: wav for best quality and large file size, mp3 for decent quality and small file size. Defaults to 'mp3'.
            
            crepe_hop_length: When `f0_method` is set to `mangio-crepe`, this controls how often it checks for pitch changes in milliseconds. Defaults to 128.
            
            input_audio: Upload your audio file here. Optional.
            
            custom_rvc_model_download_url: URL to download a custom RVC model. If provided, the model will be downloaded (if it doesn't already exist) and used for prediction, regardless of the 'rvc_model' value. Optional.
            
        """
        return self.submit_job("/predictions", protect=protect, f0_method=f0_method, rvc_model=rvc_model, index_rate=index_rate, pitch_change=pitch_change, rms_mix_rate=rms_mix_rate, filter_radius=filter_radius, output_format=output_format, crepe_hop_length=crepe_hop_length, input_audio=input_audio, custom_rvc_model_download_url=custom_rvc_model_download_url, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class dance_diffusion(FastClient):
    """
    Generated client for harmonai/dance-diffusion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="63b878a3-2f74-4d25-9782-08e6254869dc", api_key=api_key)
    
    def predictions(self, steps: int = 100, length: float = 8.0, batch_size: int = 1, model_name: str = 'maestro-150k', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            steps: Number of steps, higher numbers will give more refined output but will take longer. The maximum is 150. Defaults to 100.
            
            length: Number of seconds to generate Defaults to 8.0.
            
            batch_size: How many samples to generate Defaults to 1.
            
            model_name: Model Defaults to 'maestro-150k'.
            
        """
        return self.submit_job("/predictions", steps=steps, length=length, batch_size=batch_size, model_name=model_name, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class seamless_communication(FastClient):
    """
    Generated client for cjwbw/seamless-communication
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c3a40fb8-137c-4114-bd7a-017ebfab9502", api_key=api_key)
    
    def predictions(self, task_name: str = 'S2ST (Speech to Speech translation)', input_text_language: str = 'None', max_input_audio_length: float = 60.0, target_language_text_only: str = 'Norwegian Nynorsk', target_language_with_speech: str = 'French', input_text: Optional[str] = None, input_audio: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            task_name: Choose a task Defaults to 'S2ST (Speech to Speech translation)'.
            
            input_text_language: Specify language of the input_text for T2ST and T2TT Defaults to 'None'.
            
            max_input_audio_length: Set maximum input audio length. Defaults to 60.0.
            
            target_language_text_only: Set target language for tasks with text output only: S2TT, T2TT and ASR. Defaults to 'Norwegian Nynorsk'.
            
            target_language_with_speech: Set target language for tasks with speech output: S2ST or T2ST. Less languages are available for speech compared to text output. Defaults to 'French'.
            
            input_text: Provide input for tasks with text: T2ST and T2TT. Optional.
            
            input_audio: Provide input file for tasks with speech input: S2ST, S2TT and ASR. Optional.
            
        """
        return self.submit_job("/predictions", task_name=task_name, input_text_language=input_text_language, max_input_audio_length=max_input_audio_length, target_language_text_only=target_language_text_only, target_language_with_speech=target_language_with_speech, input_text=input_text, input_audio=input_audio, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class hyper_flux_16step(FastClient):
    """
    Generated client for bytedance/hyper-flux-16step
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="9b042e2c-660d-4be1-868a-4a22f0cf1378", api_key=api_key)
    
    def predictions(self, prompt: str, num_outputs: int = 1, aspect_ratio: str = '1:1', output_format: str = 'webp', guidance_scale: float = 3.5, output_quality: int = 80, num_inference_steps: int = 16, disable_safety_checker: bool = False, seed: Optional[int] = None, width: Optional[int] = None, height: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt for generated image
            
            num_outputs: Number of images to output. Defaults to 1.
            
            aspect_ratio: Aspect ratio for the generated image. The size will always be 1 megapixel, i.e. 1024x1024 if aspect ratio is 1:1. To use arbitrary width and height, set aspect ratio to 'custom'. Defaults to '1:1'.
            
            output_format: Format of the output images Defaults to 'webp'.
            
            guidance_scale: Guidance scale for the diffusion process Defaults to 3.5.
            
            output_quality: Quality when saving the output images, from 0 to 100. 100 is best quality, 0 is lowest quality. Not relevant for .png outputs Defaults to 80.
            
            num_inference_steps: Number of inference steps Defaults to 16.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API. See [https://replicate.com/docs/how-does-replicate-work#safety](https://replicate.com/docs/how-does-replicate-work#safety) Defaults to False.
            
            seed: Random seed. Set for reproducible generation Optional.
            
            width: Width of the generated image. Optional, only used when aspect_ratio=custom. Must be a multiple of 16 (if it's not, it will be rounded to nearest multiple of 16) Optional.
            
            height: Height of the generated image. Optional, only used when aspect_ratio=custom. Must be a multiple of 16 (if it's not, it will be rounded to nearest multiple of 16) Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, num_outputs=num_outputs, aspect_ratio=aspect_ratio, output_format=output_format, guidance_scale=guidance_scale, output_quality=output_quality, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, seed=seed, width=width, height=height, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class mars5_tts(FastClient):
    """
    Generated client for platform-kit/mars5-tts
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ece24dd4-0ae3-4a1c-826b-b7467f1a2f91", api_key=api_key)
    
    def predictions(self, text: str = "Hi there, I'm your new voice clone, powered by Mars5.", top_k: int = 95, temperature: float = 0.5, freq_penalty: int = 3, ref_audio_file: Union[MediaFile, str, bytes] = 'https://replicate.delivery/pbxt/L9a6SelzU0B2DIWeNpkNR0CKForWSbkswoUP69L0NLjLswVV/voice_sample.wav', rep_penalty_window: int = 95, ref_audio_transcript: str = "Hi there. I'm your new voice clone. Try your best to upload quality audio.", **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Text to synthesize Defaults to "Hi there, I'm your new voice clone, powered by Mars5.".
            
            top_k: top_k Defaults to 95.
            
            temperature: temperature Defaults to 0.5.
            
            freq_penalty: freq_penalty Defaults to 3.
            
            ref_audio_file: Reference audio file to clone from <= 10 seconds Defaults to 'https://replicate.delivery/pbxt/L9a6SelzU0B2DIWeNpkNR0CKForWSbkswoUP69L0NLjLswVV/voice_sample.wav'.
            
            rep_penalty_window: rep_penalty_window Defaults to 95.
            
            ref_audio_transcript: Text in the reference audio file Defaults to "Hi there. I'm your new voice clone. Try your best to upload quality audio.".
            
        """
        return self.submit_job("/predictions", text=text, top_k=top_k, temperature=temperature, freq_penalty=freq_penalty, ref_audio_file=ref_audio_file, rep_penalty_window=rep_penalty_window, ref_audio_transcript=ref_audio_transcript, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.aramintak.enna_sketch_style import enna_sketch_style
from socaity.sdk.replicate.aramintak.flux_film_foto import flux_film_foto
from socaity.sdk.replicate.aramintak.flux_frosting_lane import flux_frosting_lane
from socaity.sdk.replicate.aramintak.flux_koda import flux_koda
from socaity.sdk.replicate.aramintak.flux_softserve_anime import flux_softserve_anime
from socaity.sdk.replicate.aramintak.linnea_flux_beta import linnea_flux_beta
from socaity.sdk.replicate.aramintak.mooniverse import mooniverse


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class hunyuan_video2video(FastClient):
    """
    Generated client for zsxkib/hunyuan-video2video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="e1e6a6c2-9f32-45a0-94c4-077b5880602e", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], crf: int = 19, steps: int = 30, width: int = 768, height: int = 768, prompt: str = 'high quality nature video of a excited brown bear walking through the grass, masterpiece, best quality', flow_shift: int = 9, force_rate: int = 0, force_size: str = 'Disabled', frame_rate: int = 24, custom_width: int = 512, custom_height: int = 512, frame_load_cap: int = 101, guidance_scale: float = 6.0, keep_proportion: bool = True, denoise_strength: float = 0.85, select_every_nth: int = 1, skip_first_frames: int = 0, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: Input video file.
            
            crf: CRF value for output video quality (0-51). Lower values = better quality. Defaults to 19.
            
            steps: Number of sampling (denoising) steps. Defaults to 30.
            
            width: Output video width (divisible by 16 for best performance). Defaults to 768.
            
            height: Output video height (divisible by 16 for best performance). Defaults to 768.
            
            prompt: Text prompt describing the desired output video style. Be descriptive. Defaults to 'high quality nature video of a excited brown bear walking through the grass, masterpiece, best quality'.
            
            flow_shift: Flow shift for temporal consistency. Adjust to tweak video smoothness. Defaults to 9.
            
            force_rate: Force a new frame rate on the input video. 0 means no change. Defaults to 0.
            
            force_size: Force resize method. 'Disabled' means original size. Otherwise applies custom_width/height. Defaults to 'Disabled'.
            
            frame_rate: Frame rate of the output video. Defaults to 24.
            
            custom_width: Custom width if force_size is not 'Disabled'. Defaults to 512.
            
            custom_height: Custom height if force_size is not 'Disabled'. Defaults to 512.
            
            frame_load_cap: Max frames to load from input video. Defaults to 101.
            
            guidance_scale: Embedded guidance scale. Higher values follow the prompt more strictly. Defaults to 6.0.
            
            keep_proportion: Keep aspect ratio when resizing. If true, will adjust dimensions proportionally. Defaults to True.
            
            denoise_strength: Denoise strength (0.0 to 1.0). Higher = more deviation from input content. Defaults to 0.85.
            
            select_every_nth: Use every nth frame (1 = every frame, 2 = every second frame, etc.). Defaults to 1.
            
            skip_first_frames: Number of initial frames to skip from the input video. Defaults to 0.
            
            seed: Set a seed for reproducibility. Random by default. Optional.
            
        """
        return self.submit_job("/predictions", video=video, crf=crf, steps=steps, width=width, height=height, prompt=prompt, flow_shift=flow_shift, force_rate=force_rate, force_size=force_size, frame_rate=frame_rate, custom_width=custom_width, custom_height=custom_height, frame_load_cap=frame_load_cap, guidance_scale=guidance_scale, keep_proportion=keep_proportion, denoise_strength=denoise_strength, select_every_nth=select_every_nth, skip_first_frames=skip_first_frames, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class sana_sprint_1_6b(FastClient):
    """
    Generated client for nvidia/sana-sprint-1-6b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c153dcec-e536-4913-8b42-d020ccfb3ee2", api_key=api_key)
    
    def predictions(self, seed: int = -1, width: int = 1024, height: int = 1024, prompt: str = 'a tiny astronaut hatching from an egg on the moon', output_format: str = 'jpg', guidance_scale: float = 4.5, output_quality: int = 80, inference_steps: int = 2, intermediate_timesteps: float = 1.3, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Seed value. Set to a value less than 0 to randomize the seed Defaults to -1.
            
            width: Width of output image Defaults to 1024.
            
            height: Height of output image Defaults to 1024.
            
            prompt: Input prompt Defaults to 'a tiny astronaut hatching from an egg on the moon'.
            
            output_format: Format of the output images Defaults to 'jpg'.
            
            guidance_scale: CFG guidance scale Defaults to 4.5.
            
            output_quality: Quality when saving the output images, from 0 to 100. 100 is best quality, 0 is lowest quality. Not relevant for .png outputs Defaults to 80.
            
            inference_steps: Number of sampling steps Defaults to 2.
            
            intermediate_timesteps: Intermediate timestep value (only used when inference_steps=2, recommended values: 1.0-1.4) Defaults to 1.3.
            
        """
        return self.submit_job("/predictions", seed=seed, width=width, height=height, prompt=prompt, output_format=output_format, guidance_scale=guidance_scale, output_quality=output_quality, inference_steps=inference_steps, intermediate_timesteps=intermediate_timesteps, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class sdxl_emoji(FastClient):
    """
    Generated client for fofr/sdxl-emoji
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="759ea58d-7664-44f0-8e17-dc2f37069414", api_key=api_key)
    
    def predictions(self, width: int = 1024, height: int = 1024, prompt: str = 'An astronaut riding a rainbow unicorn', refine: str = 'no_refiner', scheduler: str = 'K_EULER', lora_scale: float = 0.6, num_outputs: int = 1, guidance_scale: float = 7.5, apply_watermark: bool = True, high_noise_frac: float = 0.8, negative_prompt: str = '', prompt_strength: float = 0.8, num_inference_steps: int = 50, disable_safety_checker: bool = False, mask: Optional[Union[MediaFile, str, bytes]] = None, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, refine_steps: Optional[int] = None, replicate_weights: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image Defaults to 1024.
            
            height: Height of output image Defaults to 1024.
            
            prompt: Input prompt Defaults to 'An astronaut riding a rainbow unicorn'.
            
            refine: Which refine style to use Defaults to 'no_refiner'.
            
            scheduler: scheduler Defaults to 'K_EULER'.
            
            lora_scale: LoRA additive scale. Only applicable on trained models. Defaults to 0.6.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            apply_watermark: Applies a watermark to enable determining if an image is generated in downstream applications. If you have other provisions for generating or deploying images safely, you can use this to disable watermarking. Defaults to True.
            
            high_noise_frac: For expert_ensemble_refiner, the fraction of noise to use Defaults to 0.8.
            
            negative_prompt: Input Negative Prompt Defaults to ''.
            
            prompt_strength: Prompt strength when using img2img / inpaint. 1.0 corresponds to full destruction of information in image Defaults to 0.8.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API. See https://replicate.com/docs/how-does-replicate-work#safety Defaults to False.
            
            mask: Input mask for inpaint mode. Black areas will be preserved, white areas will be inpainted. Optional.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for img2img or inpaint mode Optional.
            
            refine_steps: For base_image_refiner, the number of steps to refine, defaults to num_inference_steps Optional.
            
            replicate_weights: Replicate LoRA weights to use. Leave blank to use the default weights. Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, refine=refine, scheduler=scheduler, lora_scale=lora_scale, num_outputs=num_outputs, guidance_scale=guidance_scale, apply_watermark=apply_watermark, high_noise_frac=high_noise_frac, negative_prompt=negative_prompt, prompt_strength=prompt_strength, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, mask=mask, seed=seed, image=image, refine_steps=refine_steps, replicate_weights=replicate_weights, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class high_resolution_controlnet_tile(FastClient):
    """
    Generated client for fermatresearch/high-resolution-controlnet-tile
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="a3986265-ccf1-47d4-ac2e-80edc0d0ebe4", api_key=api_key)
    
    def predictions(self, hdr: float = 0.0, steps: int = 8, format: str = 'jpg', scheduler: str = 'DDIM', creativity: float = 0.35, guess_mode: bool = False, resolution: int = 2560, resemblance: float = 0.85, guidance_scale: float = 0.0, negative_prompt: str = 'teeth, tooth, open mouth, longbody, lowres, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality, mutant', lora_details_strength: float = 1.0, lora_sharpness_strength: float = 1.25, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            hdr: HDR improvement over the original image Defaults to 0.0.
            
            steps: Steps Defaults to 8.
            
            format: Format of the output. Defaults to 'jpg'.
            
            scheduler: Choose a scheduler. Defaults to 'DDIM'.
            
            creativity: Denoising strength. 1 means total destruction of the original image Defaults to 0.35.
            
            guess_mode: In this mode, the ControlNet encoder will try best to recognize the content of the input image even if you remove all prompts. Defaults to False.
            
            resolution: Image resolution Defaults to 2560.
            
            resemblance: Conditioning scale for controlnet Defaults to 0.85.
            
            guidance_scale: Scale for classifier-free guidance, should be 0. Defaults to 0.0.
            
            negative_prompt: Negative prompt Defaults to 'teeth, tooth, open mouth, longbody, lowres, bad anatomy, bad hands, missing fingers, extra digit, fewer digits, cropped, worst quality, low quality, mutant'.
            
            lora_details_strength: Strength of the image's details Defaults to 1.0.
            
            lora_sharpness_strength: Strength of the image's sharpness. We don't recommend values above 2. Defaults to 1.25.
            
            seed: Seed Optional.
            
            image: Control image for scribble controlnet Optional.
            
            prompt: Prompt for the model Optional.
            
        """
        return self.submit_job("/predictions", hdr=hdr, steps=steps, format=format, scheduler=scheduler, creativity=creativity, guess_mode=guess_mode, resolution=resolution, resemblance=resemblance, guidance_scale=guidance_scale, negative_prompt=negative_prompt, lora_details_strength=lora_details_strength, lora_sharpness_strength=lora_sharpness_strength, seed=seed, image=image, prompt=prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.nightmareai.disco_diffusion import disco_diffusion
from socaity.sdk.replicate.nightmareai.latent_sr import latent_sr
from socaity.sdk.replicate.nightmareai.real_esrgan import real_esrgan


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class merge_img(FastClient):
    """
    Generated client for lucataco/merge-img
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="81ac2500-951a-40f0-bd75-ca22308ea8b2", api_key=api_key)
    
    def predictions(self, background: Optional[Union[MediaFile, str, bytes]] = None, foreground: Optional[Union[MediaFile, str, bytes]] = None, position_x: Optional[int] = None, position_y: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            background: JPG image to be used as background Optional.
            
            foreground: PNG image with transparency to be used as foreground Optional.
            
            position_x: X coordinate for foreground image position (optional, defaults to center) Optional.
            
            position_y: Y coordinate for foreground image position (optional, defaults to center) Optional.
            
        """
        return self.submit_job("/predictions", background=background, foreground=foreground, position_x=position_x, position_y=position_y, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class material_diffusion(FastClient):
    """
    Generated client for tstramer/material-diffusion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ccb73456-e827-42e9-8e65-e571b7bd0c02", api_key=api_key)
    
    def predictions(self, width: int = 512, height: int = 512, prompt: str = '', scheduler: str = 'K-LMS', num_outputs: int = 1, guidance_scale: float = 7.5, prompt_strength: float = 0.8, num_inference_steps: int = 50, mask: Optional[Union[MediaFile, str, bytes]] = None, seed: Optional[int] = None, init_image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image. Maximum size is 1024x768 or 768x1024 because of memory limits Defaults to 512.
            
            height: Height of output image. Maximum size is 1024x768 or 768x1024 because of memory limits Defaults to 512.
            
            prompt: Input prompt Defaults to ''.
            
            scheduler: Choose a scheduler. If you use an init image, PNDM will be used Defaults to 'K-LMS'.
            
            num_outputs: Number of images to output. If the NSFW filter is triggered, you may get fewer outputs than this. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            prompt_strength: Prompt strength when using init image. 1.0 corresponds to full destruction of information in init image Defaults to 0.8.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            mask: Black and white image to use as mask for inpainting over init_image. Black pixels are inpainted and white pixels are preserved. Tends to work better with prompt strength of 0.5-0.7. Consider using https://replicate.com/andreasjansson/stable-diffusion-inpainting instead. Optional.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            init_image: Inital image to generate variations of. Will be resized to the specified width and height Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, scheduler=scheduler, num_outputs=num_outputs, guidance_scale=guidance_scale, prompt_strength=prompt_strength, num_inference_steps=num_inference_steps, mask=mask, seed=seed, init_image=init_image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class damo_text_to_video(FastClient):
    """
    Generated client for cjwbw/damo-text-to-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="6ab55669-b0df-4a2f-be3a-8f641973eb50", api_key=api_key)
    
    def predictions(self, fps: int = 8, prompt: str = 'An astronaut riding a horse', num_frames: int = 16, num_inference_steps: int = 50, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            fps: fps for the output video Defaults to 8.
            
            prompt: Input prompt Defaults to 'An astronaut riding a horse'.
            
            num_frames: Number of frames for the output video Defaults to 16.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", fps=fps, prompt=prompt, num_frames=num_frames, num_inference_steps=num_inference_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class supir(FastClient):
    """
    Generated client for cjwbw/supir
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="05ee9d66-1243-46d8-92c8-6cd343820df4", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], s_cfg: float = 7.5, s_churn: float = 5.0, s_noise: float = 1.003, upscale: int = 1, a_prompt: str = 'Cinematic, High Contrast, highly detailed, taken using a Canon EOS R camera, hyper detailed photo - realistic maximum detail, 32k, Color Grading, ultra HD, extreme meticulous detailing, skin pore detailing, hyper sharpness, perfect without deformations.', min_size: float = 1024.0, n_prompt: str = 'painting, oil painting, illustration, drawing, art, sketch, oil painting, cartoon, CG Style, 3D render, unreal engine, blurring, dirty, messy, worst quality, low quality, frames, watermark, signature, jpeg artifacts, deformed, lowres, over-smooth', s_stage1: int = -1, s_stage2: float = 1.0, edm_steps: int = 50, use_llava: bool = True, linear: bool = False, model_name: str = 'SUPIR-v0Q', color_fix_type: str = 'Wavelet', spt_linear: float = 1.0, linear_s_stage2: bool = False, spt_linear_s_stage2: float = 0.0, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Low quality input image.
            
            s_cfg:  Classifier-free guidance scale for prompts. Defaults to 7.5.
            
            s_churn: Original churn hy-param of EDM. Defaults to 5.0.
            
            s_noise: Original noise hy-param of EDM. Defaults to 1.003.
            
            upscale: Upsampling ratio of given inputs. Defaults to 1.
            
            a_prompt: Additive positive prompt for the inputs. Defaults to 'Cinematic, High Contrast, highly detailed, taken using a Canon EOS R camera, hyper detailed photo - realistic maximum detail, 32k, Color Grading, ultra HD, extreme meticulous detailing, skin pore detailing, hyper sharpness, perfect without deformations.'.
            
            min_size: Minimum resolution of output images. Defaults to 1024.0.
            
            n_prompt: Negative prompt for the inputs. Defaults to 'painting, oil painting, illustration, drawing, art, sketch, oil painting, cartoon, CG Style, 3D render, unreal engine, blurring, dirty, messy, worst quality, low quality, frames, watermark, signature, jpeg artifacts, deformed, lowres, over-smooth'.
            
            s_stage1: Control Strength of Stage1 (negative means invalid). Defaults to -1.
            
            s_stage2: Control Strength of Stage2. Defaults to 1.0.
            
            edm_steps: Number of steps for EDM Sampling Schedule. Defaults to 50.
            
            use_llava: Use LLaVA model to get captions. Defaults to True.
            
            linear: Linearly (with sigma) increase CFG from 'spt_linear_CFG' to s_cfg. Defaults to False.
            
            model_name: Choose a model. SUPIR-v0Q is the default training settings with paper. SUPIR-v0F is high generalization and high image quality in most cases. Training with light degradation settings. Stage1 encoder of SUPIR-v0F remains more details when facing light degradations. Defaults to 'SUPIR-v0Q'.
            
            color_fix_type: Color Fixing Type.. Defaults to 'Wavelet'.
            
            spt_linear: Start point of linearly increasing CFG. Defaults to 1.0.
            
            linear_s_stage2: Linearly (with sigma) increase s_stage2 from 'spt_linear_s_stage2' to s_stage2. Defaults to False.
            
            spt_linear_s_stage2: Start point of linearly increasing s_stage2. Defaults to 0.0.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", image=image, s_cfg=s_cfg, s_churn=s_churn, s_noise=s_noise, upscale=upscale, a_prompt=a_prompt, min_size=min_size, n_prompt=n_prompt, s_stage1=s_stage1, s_stage2=s_stage2, edm_steps=edm_steps, use_llava=use_llava, linear=linear, model_name=model_name, color_fix_type=color_fix_type, spt_linear=spt_linear, linear_s_stage2=linear_s_stage2, spt_linear_s_stage2=spt_linear_s_stage2, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class semantic_segment_anything(FastClient):
    """
    Generated client for cjwbw/semantic-segment-anything
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="04c66564-04a1-43c6-85e1-5ce7a90f4339", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], output_json: bool = True, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            output_json: return raw json output Defaults to True.
            
        """
        return self.submit_job("/predictions", image=image, output_json=output_json, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.pollinations.modnet import modnet
from socaity.sdk.replicate.pollinations.real_basicvsr_video_superresolution import real_basicvsr_video_superresolution
from socaity.sdk.replicate.pollinations.stable_diffusion_dance import stable_diffusion_dance
from socaity.sdk.replicate.pollinations.tune_a_video import tune_a_video


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class swinir(FastClient):
    """
    Generated client for jingyunliang/swinir
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="a38caf79-16b9-494d-a212-5191e6e72799", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], jpeg: int = 40, noise: int = 15, task_type: str = 'Real-World Image Super-Resolution-Large', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: input image
            
            jpeg: scale factor, activated for JPEG Compression Artifact Reduction. Leave it as default or arbitrary if other tasks are selected Defaults to 40.
            
            noise: noise level, activated for Grayscale Image Denoising and Color Image Denoising. Leave it as default or arbitrary if other tasks are selected Defaults to 15.
            
            task_type: Choose a task Defaults to 'Real-World Image Super-Resolution-Large'.
            
        """
        return self.submit_job("/predictions", image=image, jpeg=jpeg, noise=noise, task_type=task_type, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class deepseek_r1(FastClient):
    """
    Generated client for deepseek-ai/deepseek-r1
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2473ea32-3908-4d16-af2b-809d6b5a6eb7", api_key=api_key)
    
    def predictions(self, top_p: float = 1.0, prompt: str = '', max_tokens: int = 20480, temperature: float = 0.1, presence_penalty: float = 0.0, frequency_penalty: float = 0.0, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            top_p: Top-p (nucleus) sampling Defaults to 1.0.
            
            prompt: Prompt Defaults to ''.
            
            max_tokens: The maximum number of tokens the model should generate as output. Defaults to 20480.
            
            temperature: The value used to modulate the next token probabilities. Defaults to 0.1.
            
            presence_penalty: Presence penalty Defaults to 0.0.
            
            frequency_penalty: Frequency penalty Defaults to 0.0.
            
        """
        return self.submit_job("/predictions", top_p=top_p, prompt=prompt, max_tokens=max_tokens, temperature=temperature, presence_penalty=presence_penalty, frequency_penalty=frequency_penalty, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class tooncrafter(FastClient):
    """
    Generated client for fofr/tooncrafter
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0bbfd0a9-4f09-4f7a-aaa1-faff1b296218", api_key=api_key)
    
    def predictions(self, image_1: Union[MediaFile, str, bytes], image_2: Union[MediaFile, str, bytes], loop: bool = False, prompt: str = '', max_width: int = 512, max_height: int = 512, interpolate: bool = False, negative_prompt: str = '', color_correction: bool = True, seed: Optional[int] = None, image_3: Optional[Union[MediaFile, str, bytes]] = None, image_4: Optional[Union[MediaFile, str, bytes]] = None, image_5: Optional[Union[MediaFile, str, bytes]] = None, image_6: Optional[Union[MediaFile, str, bytes]] = None, image_7: Optional[Union[MediaFile, str, bytes]] = None, image_8: Optional[Union[MediaFile, str, bytes]] = None, image_9: Optional[Union[MediaFile, str, bytes]] = None, image_10: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image_1: First input image
            
            image_2: Second input image
            
            loop: Loop the video Defaults to False.
            
            prompt: prompt Defaults to ''.
            
            max_width: Maximum width of the video Defaults to 512.
            
            max_height: Maximum height of the video Defaults to 512.
            
            interpolate: Enable 2x interpolation using FILM Defaults to False.
            
            negative_prompt: Things you do not want to see in your video Defaults to ''.
            
            color_correction: If the colors are coming out strange, or if the colors between your input images are very different, disable this Defaults to True.
            
            seed: Set a seed for reproducibility. Random by default. Optional.
            
            image_3: Third input image (optional) Optional.
            
            image_4: Fourth input image (optional) Optional.
            
            image_5: Fifth input image (optional) Optional.
            
            image_6: Sixth input image (optional) Optional.
            
            image_7: Seventh input image (optional) Optional.
            
            image_8: Eighth input image (optional) Optional.
            
            image_9: Ninth input image (optional) Optional.
            
            image_10: Tenth input image (optional) Optional.
            
        """
        return self.submit_job("/predictions", image_1=image_1, image_2=image_2, loop=loop, prompt=prompt, max_width=max_width, max_height=max_height, interpolate=interpolate, negative_prompt=negative_prompt, color_correction=color_correction, seed=seed, image_3=image_3, image_4=image_4, image_5=image_5, image_6=image_6, image_7=image_7, image_8=image_8, image_9=image_9, image_10=image_10, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class yolox(FastClient):
    """
    Generated client for daanelson/yolox
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="cd41e5da-0dd9-4893-872a-df2692fc91aa", api_key=api_key)
    
    def predictions(self, input_image: Union[MediaFile, str, bytes], nms: float = 0.3, conf: float = 0.3, tsize: int = 640, model_name: str = 'yolox-s', return_json: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_image: Path to an image
            
            nms: NMS threshold: NMS removes redundant detections. Detections with overlap percentage (IOU) above this threshold are consider redundant to each other and only one of them will be kept Defaults to 0.3.
            
            conf: Confidence threshold: Only detections with confidence higher are kept Defaults to 0.3.
            
            tsize: Resize image to this size Defaults to 640.
            
            model_name: Model name Defaults to 'yolox-s'.
            
            return_json: Return results in json format Defaults to False.
            
        """
        return self.submit_job("/predictions", input_image=input_image, nms=nms, conf=conf, tsize=tsize, model_name=model_name, return_json=return_json, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class sam_2_video(FastClient):
    """
    Generated client for meta/sam-2-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="d02baeff-417a-4506-b151-8c40e5fa3ee3", api_key=api_key)
    
    def predictions(self, input_video: Union[MediaFile, str, bytes], click_coordinates: str, mask_type: str = 'binary', video_fps: int = 30, click_frames: str = '0', click_labels: str = '1', output_video: bool = False, output_format: str = 'webp', output_quality: int = 80, annotation_type: str = 'mask', click_object_ids: str = '', output_frame_interval: int = 1, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_video: Input video file path
            
            click_coordinates: Click coordinates as '[x,y],[x,y],...'. Determines number of clicks.
            
            mask_type: Mask type: binary (B&W), highlighted (colored overlay), or greenscreen Defaults to 'binary'.
            
            video_fps: Video output frame rate (ignored for image sequence) Defaults to 30.
            
            click_frames: Frame indices for clicks as '0,0,150,0'. Auto-extends if shorter than coordinates. Defaults to '0'.
            
            click_labels: Click types (1=foreground, 0=background) as '1,1,0,1'. Auto-extends if shorter than coordinates. Defaults to '1'.
            
            output_video: True for video output, False for image sequence Defaults to False.
            
            output_format: Image format for sequence (ignored for video) Defaults to 'webp'.
            
            output_quality: JPG/WebP compression quality (0-100, ignored for PNG and video) Defaults to 80.
            
            annotation_type: Annotation type: mask only, bounding box only, or both (ignored for binary and greenscreen) Defaults to 'mask'.
            
            click_object_ids: Object labels for clicks as 'person,dog,cat'. Auto-generates if missing or incomplete. Defaults to ''.
            
            output_frame_interval: Output every Nth frame. 1=all frames, 2=every other, etc. Defaults to 1.
            
        """
        return self.submit_job("/predictions", input_video=input_video, click_coordinates=click_coordinates, mask_type=mask_type, video_fps=video_fps, click_frames=click_frames, click_labels=click_labels, output_video=output_video, output_format=output_format, output_quality=output_quality, annotation_type=annotation_type, click_object_ids=click_object_ids, output_frame_interval=output_frame_interval, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from typing import Dict, Set
from pathlib import Path
from datetime import datetime, timedelta
from fastsdk.service_management import ServiceManager, FileSystemStore
from fastsdk import ServiceDefinition
from fastsdk.sdk_factory import create_sdk
from fastsdk.utils import normalize_name_for_py
from socaity.core.socaity_backend_client import SocaityBackendClient


class SocaityServiceManager(ServiceManager):
    SDK_ROOT = Path(__file__).parent.parent / "sdk"
    OFFICIAL_SDK_DIR = SDK_ROOT / "official"
    COMMUNITY_SDK_DIR = SDK_ROOT / "community"
    REPLICATE_SDK_DIR = SDK_ROOT / "replicate"
    CACHE_DIR = SDK_ROOT / "cache"
    CACHE_TTL_MINUTES = 15

    def __init__(self):
        super().__init__(service_store=FileSystemStore(self.CACHE_DIR))
        self.socaity_backend_client = SocaityBackendClient()
        self._created_sdks: Dict[str, Path] = {}  # class_name -> save_path
        self._deleted_sdks: Dict[str, Path] = {}  # model_name -> save_path
        self.update_package()

    def _is_cache_stale(self) -> bool:
        """Check if the cache is older than the TTL by examining cache directory modification time"""
        if not self.CACHE_DIR.exists():
            return True  # No cache exists, needs update
        
        try:
            cache_mtime = datetime.fromtimestamp(self.CACHE_DIR.stat().st_mtime)
            cache_age = datetime.now() - cache_mtime
            ttl = timedelta(minutes=self.CACHE_TTL_MINUTES)
            
            return cache_age > ttl
        except OSError:
            return True  # If we can't check, assume stale

    def _get_save_path(self, provider: str, username: str, model_name: str, is_official: bool = False) -> Path:
        """Get the appropriate save path based on provider and model info"""
        if provider.lower() == "replicate":
            return self.REPLICATE_SDK_DIR / username / f"{model_name}.py"
        elif is_official:
            return self.OFFICIAL_SDK_DIR / f"{model_name}.py"
        else:
            return self.COMMUNITY_SDK_DIR / f"{model_name}.py"

    def _parse_display_name(self, display_name: str) -> tuple[str, str]:
        """Parse display name into username and model name"""
        if "/" in display_name:
            username, model_name = display_name.split("/", 1)
        else:
            username, model_name = "official", display_name
        
        return normalize_name_for_py(username), normalize_name_for_py(model_name)

    def update_package(self) -> None:
        """Update the package with latest model changes"""
        if not self._is_cache_stale():
            return
        
        package_updates = self.socaity_backend_client.update_package(self.service_store.get_version_index())
        if not package_updates or not package_updates.get("updates"):
            return

        print("Updating package...")
        for update_item in package_updates["updates"]:
            if update_item.get("action") == "delete":
                self._handle_model_deletion(update_item)
            else:
                self._handle_model_update(update_item)

        self._update_init_files()
        # Touch the cache directory to update its modification time
        self._touch_cache_dir()

    def _touch_cache_dir(self) -> None:
        """Update the cache directory modification time to current time"""
        if self.CACHE_DIR.exists():
            self.CACHE_DIR.touch()

    def force_update_package(self) -> None:
        """Force update the package regardless of cache TTL"""
        self.update_package()

    def _handle_model_deletion(self, update_item: Dict) -> None:
        """Handle deletion of a model"""
        mhi = update_item.get("model_hosting_info", {})
        hosted_model_id = mhi.get("id")
        print(f"Deleting {hosted_model_id}...")
        
        try:
            # Get provider and display name for path calculation
            provider = update_item.get("provider", "socaity")
            display_name = update_item.get("display_name", "")
            username, model_name = self._parse_display_name(display_name)
            
            # For socaity models, we need to check both official and community dirs
            if provider and provider.lower() != "replicate":
                official_path = self.OFFICIAL_SDK_DIR / f"{model_name}.py"
                community_path = self.COMMUNITY_SDK_DIR / f"{model_name}.py"
                
                if official_path.exists():
                    save_path = official_path
                elif community_path.exists():
                    save_path = community_path
                else:
                    save_path = None
            else:
                save_path = self._get_save_path(provider, username, model_name, False)
                
            if save_path and save_path.exists():
                self._deleted_sdks[model_name] = save_path
                save_path.unlink()
        except Exception as e:
            print(f"Error deleting file {hosted_model_id}: {e}")

        try:
            self.service_store.delete_service(hosted_model_id)
        except Exception as e:
            print(f"Error deleting service {hosted_model_id}: {e}")

    def _handle_model_update(self, update_item: Dict) -> None:
        """Handle update of a model"""
        mhi = update_item.get("model_hosting_info", {})
        service_def_data = update_item.get("service_definition")
        hosted_model_id = mhi.get("id")
        
        print(f"Updating {hosted_model_id}...")
        
        if not service_def_data:
            print(f"No service definition for {hosted_model_id}. Skipping it.")
            return

        # Convert the dictionary to a ServiceDefinition object if needed
        if isinstance(service_def_data, dict):
            service_def = ServiceDefinition(**service_def_data)
        else:
            service_def = service_def_data

        # Extract information from the update item
        provider = update_item.get("provider", "socaity")
        display_name = update_item.get("display_name", "")
        is_official = update_item.get("is_official", False)
        
        username, model_name = self._parse_display_name(display_name)
        
        # Determine if model is official (only for socaity models)  
        is_official = is_official if provider.lower() != "replicate" else False
        
        save_path = self._get_save_path(provider, username, model_name, is_official)
        
        # Normalize the model name for use as a Python class name
        class_name = normalize_name_for_py(model_name)
        
        # Use the service definition directly (already contains all needed information)
        try:
            file_path, actual_class_name, _ = create_sdk(
                service_definition=service_def,
                save_path=str(save_path),
                class_name=class_name  # Use just the model name for the class name
            )
            self._created_sdks[actual_class_name] = Path(file_path)
        except Exception as e:
            print(f"Error creating SDK for {hosted_model_id}: {e}")

        # Store the service definition in the service store for caching and reload
        try:
            self.service_store.save_service(service_def)
        except Exception as e:
            print(f"Warning: Failed to save service definition for {hosted_model_id}: {e}")

    def _update_init_files(self) -> None:
        """Update all __init__.py files with current imports"""
        self._ensure_sdk_directories()
        
        # Update main SDK __init__.py (only import official models)
        main_content = "from socaity.sdk.official import *"
        self._write_init_content(self.SDK_ROOT, main_content)
        
        # Update official SDK __init__.py
        official_imports = self._generate_imports(target="official")
        self._write_init_file(self.OFFICIAL_SDK_DIR, official_imports)
        
        # Update community SDK __init__.py
        community_imports = self._generate_imports(target="community")
        self._write_init_file(self.COMMUNITY_SDK_DIR, community_imports)
        
        # Update replicate username-specific __init__.py files
        self._update_replicate_init_files()

    def _ensure_sdk_directories(self) -> None:
        """Ensure all necessary SDK directories exist"""
        self.SDK_ROOT.mkdir(exist_ok=True)
        self.OFFICIAL_SDK_DIR.mkdir(exist_ok=True)
        self.COMMUNITY_SDK_DIR.mkdir(exist_ok=True)
        self.REPLICATE_SDK_DIR.mkdir(exist_ok=True)

    def _update_replicate_init_files(self) -> None:
        """Update __init__.py files for each replicate username directory"""
        # Get all replicate usernames from created SDKs
        replicate_usernames = set()
        for class_name, file_path in self._created_sdks.items():
            if "replicate" in str(file_path):
                try:
                    relative_path = file_path.relative_to(self.REPLICATE_SDK_DIR)
                    username = relative_path.parts[0]  # First part is the username
                    replicate_usernames.add(username)
                except ValueError:
                    continue
        
        # Create __init__.py for each username directory
        for username in replicate_usernames:
            username_dir = self.REPLICATE_SDK_DIR / username
            if username_dir.exists():
                username_imports = self._generate_replicate_imports(username)
                self._write_init_file(username_dir, username_imports)

    def _get_path_as_import(self, file_path: Path) -> str:
        """Get the path as import for a given file path"""
        path_as_import = str(file_path).replace('\\', '/')
        if path_as_import.endswith('.py'):
            path_as_import = path_as_import[:-3]  # Remove .py extension
        path_as_import = path_as_import.replace('/', '.')
        return path_as_import

    def _generate_replicate_imports(self, username: str) -> Set[str]:
        """Generate import statements specifically for replicate username directories"""
        imports = set()
        
        for class_name, file_path in self._created_sdks.items():
            # Check if this file belongs to this specific username
            if "replicate" in str(file_path) and username in str(file_path):
                try:
                    # Get the relative path from SDK_ROOT
                    relative_path = file_path.relative_to(self.SDK_ROOT)
                    # Convert path to import format
                    path_as_import = self._get_path_as_import(relative_path)
                    # Construct import path
                    import_path = f"socaity.sdk.{path_as_import}"
                    import_stmt = f"from {import_path} import {class_name}"
                    imports.add(import_stmt)
                except Exception as e:
                    print(f"Error processing replicate import for {file_path}: {e}")
                    continue

        # Add existing imports from the username directory
        username_dir = self.REPLICATE_SDK_DIR / username
        try:
            old_imports = self._load_imports_from_init_py(username_dir / "__init__.py")
            imports.update(old_imports)
        except FileNotFoundError:
            pass

        # Remove deleted imports
        self._remove_deleted_imports(imports)
        return imports

    def _generate_imports(self, target: str = None) -> Set[str]:
        """Generate import statements for SDK files
        
        Args:
            target: The target for imports - "official", "community"
        """
        imports = set()
        
        for class_name, file_path in self._created_sdks.items():
            # Filter based on target
            if target is not None and target not in str(file_path):
                continue

            try:
                # Get the relative path from SDK_ROOT
                relative_path = file_path.relative_to(self.SDK_ROOT)
                # Convert path to import format
                path_as_import = self._get_path_as_import(relative_path)
                # Construct import path
                import_path = f"socaity.sdk.{path_as_import}"
                import_stmt = f"from {import_path} import {class_name}"
                imports.add(import_stmt)
            except Exception as e:
                print(f"Error processing import for {file_path}: {e}")
                continue

        # Add existing imports
        if target == "official":
            init_path = self.OFFICIAL_SDK_DIR
        elif target == "community":
            init_path = self.COMMUNITY_SDK_DIR
        else:
            init_path = self.SDK_ROOT
            
        try:
            old_imports = self._load_imports_from_init_py(init_path / "__init__.py")
            imports.update(old_imports)
        except FileNotFoundError:
            pass

        # Remove deleted imports
        self._remove_deleted_imports(imports)
        return imports

    def _write_init_content(self, directory: Path, content: str) -> None:
        """Write specific content to __init__.py file"""
        init_file = directory / "__init__.py"
        init_file.write_text(content)

    def _write_init_file(self, directory: Path, imports: Set[str]) -> None:
        """Write imports to __init__.py file"""
        init_file = directory / "__init__.py"
        # Sort imports to have common imports first, then alphabetically
        sorted_imports = sorted(imports, key=lambda x: ('.common.' not in x, x))
        init_file.write_text("\n".join(sorted_imports))

    def _load_imports_from_init_py(self, path: Path) -> Set[str]:
        """Load existing imports from __init__.py file"""
        imports = set()
        if path.exists():
            for line in path.read_text().splitlines():
                if line.strip() and line.startswith("from"):
                    imports.add(line.strip())
        return imports

    def _remove_deleted_imports(self, imports: Set[str]) -> None:
        """Remove imports of deleted SDKs from the given imports set"""
        imports_to_remove = {
            imp
            for imp in imports 
            for del_path in self._deleted_sdks.values() 
            if str(del_path) in imp
        }
        imports.difference_update(imports_to_remove)


if __name__ == "__main__":
    sm = SocaityServiceManager()



from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class autotune(FastClient):
    """
    Generated client for nateraw/autotune
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="bb298a70-019d-4d23-b498-2888f630419f", api_key=api_key)
    
    def predictions(self, audio_file: Union[MediaFile, str, bytes], scale: str = 'closest', output_format: str = 'wav', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio_file: Audio input file
            
            scale: Strategy for normalizing audio. Defaults to 'closest'.
            
            output_format: Output format for generated audio. Defaults to 'wav'.
            
        """
        return self.submit_job("/predictions", audio_file=audio_file, scale=scale, output_format=output_format, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class mask_clothing(FastClient):
    """
    Generated client for ahmdyassr/mask-clothing
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="09115fc3-0100-42e0-b034-3480586c9990", api_key=api_key)
    
    def predictions(self, face_mask: bool = False, adjustment: int = 0, face_adjustment: int = 0, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            face_mask: Mask face found in this image? Defaults to False.
            
            adjustment: Mask adjustment Defaults to 0.
            
            face_adjustment: Face mask adjustment Defaults to 0.
            
            image: Mask clothing found in this image Optional.
            
        """
        return self.submit_job("/predictions", face_mask=face_mask, adjustment=adjustment, face_adjustment=face_adjustment, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class kokoro_82m(FastClient):
    """
    Generated client for jaaari/kokoro-82m
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="40170a05-bca7-49a3-b285-c34c28aba8ec", api_key=api_key)
    
    def predictions(self, text: str, speed: float = 1.0, voice: str = 'af_bella', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Text input (long text is automatically split)
            
            speed: Speech speed multiplier (0.5 = half speed, 2.0 = double speed) Defaults to 1.0.
            
            voice: Voice to use for synthesis Defaults to 'af_bella'.
            
        """
        return self.submit_job("/predictions", text=text, speed=speed, voice=voice, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import List, Union, Any


class gte_qwen2_7b_instruct(FastClient):
    """
    Generated client for cuuupid/gte-qwen2-7b-instruct
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c704672f-cd24-4875-aa3f-300e0639e0f2", api_key=api_key)
    
    def predictions(self, text: Union[List[Any], str], **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Texts to embed
            
        """
        return self.submit_job("/predictions", text=text, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class mimic_motion(FastClient):
    """
    Generated client for zsxkib/mimic-motion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="fafb0f0b-99d8-44cc-9a9a-da460afbae86", api_key=api_key)
    
    def predictions(self, motion_video: Union[MediaFile, str, bytes], appearance_image: Union[MediaFile, str, bytes], chunk_size: int = 16, resolution: int = 576, sample_stride: int = 2, frames_overlap: int = 6, guidance_scale: float = 2.0, noise_strength: float = 0.0, denoising_steps: int = 25, checkpoint_version: str = 'v1-1', output_frames_per_second: int = 15, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            motion_video: Reference video file containing the motion to be mimicked
            
            appearance_image: Reference image file for the appearance of the generated video
            
            chunk_size: Number of frames to generate in each processing chunk Defaults to 16.
            
            resolution: Height of the output video in pixels. Width is automatically calculated. Defaults to 576.
            
            sample_stride: Interval for sampling frames from the reference video. Higher values skip more frames. Defaults to 2.
            
            frames_overlap: Number of overlapping frames between chunks for smoother transitions Defaults to 6.
            
            guidance_scale: Strength of guidance towards the reference. Higher values adhere more closely to the reference but may reduce creativity. Defaults to 2.0.
            
            noise_strength: Strength of noise augmentation. Higher values add more variation but may reduce coherence with the reference. Defaults to 0.0.
            
            denoising_steps: Number of denoising steps in the diffusion process. More steps can improve quality but increase processing time. Defaults to 25.
            
            checkpoint_version: Choose the checkpoint version to use Defaults to 'v1-1'.
            
            output_frames_per_second: Frames per second of the output video. Affects playback speed. Defaults to 15.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", motion_video=motion_video, appearance_image=appearance_image, chunk_size=chunk_size, resolution=resolution, sample_stride=sample_stride, frames_overlap=frames_overlap, guidance_scale=guidance_scale, noise_strength=noise_strength, denoising_steps=denoising_steps, checkpoint_version=checkpoint_version, output_frames_per_second=output_frames_per_second, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import List, Union, Any, Optional

from media_toolkit import MediaFile


class gpt_4_1_mini(FastClient):
    """
    Generated client for openai/gpt-4-1-mini
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="770b7879-147a-4e15-a014-45ffe07dfbd5", api_key=api_key)
    
    def predictions(self, top_p: float = 1.0, image_input: Union[List[Any], MediaFile, str, bytes] = [], temperature: float = 1.0, presence_penalty: float = 0.0, frequency_penalty: float = 0.0, max_completion_tokens: int = 4096, prompt: Optional[str] = None, system_prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            top_p: Nucleus sampling parameter - the model considers the results of the tokens with top_p probability mass. (0.1 means only the tokens comprising the top 10% probability mass are considered.) Defaults to 1.0.
            
            image_input: List of images to send to the model Defaults to [].
            
            temperature: Sampling temperature between 0 and 2 Defaults to 1.0.
            
            presence_penalty: Presence penalty parameter - positive values penalize new tokens based on whether they appear in the text so far, increasing the model's likelihood to talk about new topics. Defaults to 0.0.
            
            frequency_penalty: Frequency penalty parameter - positive values penalize the repetition of tokens. Defaults to 0.0.
            
            max_completion_tokens: Maximum number of completion tokens to generate Defaults to 4096.
            
            prompt: The prompt to send to the model. Do not use if using messages. Optional.
            
            system_prompt: System prompt to set the assistant's behavior Optional.
            
        """
        return self.submit_job("/predictions", top_p=top_p, image_input=image_input, temperature=temperature, presence_penalty=presence_penalty, frequency_penalty=frequency_penalty, max_completion_tokens=max_completion_tokens, prompt=prompt, system_prompt=system_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.usamaehsan.controlnet_1_1_x_realistic_vision_v2_0 import controlnet_1_1_x_realistic_vision_v2_0
from socaity.sdk.replicate.usamaehsan.controlnet_x_ip_adapter_realistic_vision_v5 import controlnet_x_ip_adapter_realistic_vision_v5


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class swin2sr(FastClient):
    """
    Generated client for mv-lab/swin2sr
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="6e37ff20-c897-459b-88b3-7214da99faca", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], task: str = 'real_sr', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            task: Choose a task Defaults to 'real_sr'.
            
        """
        return self.submit_job("/predictions", image=image, task=task, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class ic_light_background(FastClient):
    """
    Generated client for zsxkib/ic-light-background
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="1fb36653-7ac0-4755-8d93-af13540a00eb", api_key=api_key)
    
    def predictions(self, prompt: str, subject_image: Union[MediaFile, str, bytes], background_image: Union[MediaFile, str, bytes], cfg: float = 2.0, steps: int = 25, width: int = 512, height: int = 640, light_source: str = 'Use Background Image', highres_scale: float = 1.5, output_format: str = 'webp', compute_normal: bool = False, output_quality: int = 80, appended_prompt: str = 'best quality', highres_denoise: float = 0.5, negative_prompt: str = 'lowres, bad anatomy, bad hands, cropped, worst quality', number_of_images: int = 1, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: A text description guiding the relighting and generation process
            
            subject_image: The main foreground image to be relighted
            
            background_image: The background image that will be used to relight the main foreground image
            
            cfg: Classifier-Free Guidance scale - higher values encourage adherence to prompt, lower values encourage more creative interpretation Defaults to 2.0.
            
            steps: The number of diffusion steps to perform during generation (more steps generally improves image quality but increases processing time) Defaults to 25.
            
            width: The width of the generated images in pixels Defaults to 512.
            
            height: The height of the generated images in pixels Defaults to 640.
            
            light_source: The type and position of lighting to apply to the initial background latent Defaults to 'Use Background Image'.
            
            highres_scale: The multiplier for the final output resolution relative to the initial latent resolution Defaults to 1.5.
            
            output_format: The image file format of the generated output images Defaults to 'webp'.
            
            compute_normal: Whether to compute the normal maps (slower but provides additional output images) Defaults to False.
            
            output_quality: The image compression quality (for lossy formats like JPEG and WebP). 100 = best quality, 0 = lowest quality. Defaults to 80.
            
            appended_prompt: Additional text to be appended to the main prompt, enhancing image quality Defaults to 'best quality'.
            
            highres_denoise: Controls the amount of denoising applied when refining the high resolution output (higher = more adherence to the upscaled latent, lower = more creative details added) Defaults to 0.5.
            
            negative_prompt: A text description of attributes to avoid in the generated images Defaults to 'lowres, bad anatomy, bad hands, cropped, worst quality'.
            
            number_of_images: The number of unique images to generate from the given input and settings Defaults to 1.
            
            seed: A fixed random seed for reproducible results (omit this parameter for a randomized seed) Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, subject_image=subject_image, background_image=background_image, cfg=cfg, steps=steps, width=width, height=height, light_source=light_source, highres_scale=highres_scale, output_format=output_format, compute_normal=compute_normal, output_quality=output_quality, appended_prompt=appended_prompt, highres_denoise=highres_denoise, negative_prompt=negative_prompt, number_of_images=number_of_images, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class text2tex(FastClient):
    """
    Generated client for adirik/text2tex
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="617a3bde-432c-4750-b2b5-df52f4eedd7a", api_key=api_key)
    
    def predictions(self, prompt: str, obj_file: Union[MediaFile, str, bytes], ddim_steps: int = 50, update_mode: str = 'heuristic', new_strength: float = 1.0, update_steps: int = 20, num_viewpoints: int = 36, viewpoint_mode: str = 'predefined', negative_prompt: str = '', update_strength: float = 0.3, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt to generate a 3D object.
            
            obj_file: 3D object (shape) file to generate the texture onto
            
            ddim_steps: Number of steps for DDIM Defaults to 50.
            
            update_mode: Update mode Defaults to 'heuristic'.
            
            new_strength: Amount of DDIM steps for the new view Defaults to 1.0.
            
            update_steps: Number of update steps Defaults to 20.
            
            num_viewpoints: Number of viewpoints Defaults to 36.
            
            viewpoint_mode: Viewpoint mode Defaults to 'predefined'.
            
            negative_prompt: Negative prompt to generate a 3D object. Defaults to ''.
            
            update_strength: Amount of DDIM steps for updating the view Defaults to 0.3.
            
            seed: Seed Optional.
            
        """
        return self.submit_job("/predictions", prompt=prompt, obj_file=obj_file, ddim_steps=ddim_steps, update_mode=update_mode, new_strength=new_strength, update_steps=update_steps, num_viewpoints=num_viewpoints, viewpoint_mode=viewpoint_mode, negative_prompt=negative_prompt, update_strength=update_strength, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class img_and_audio2video(FastClient):
    """
    Generated client for lucataco/img-and-audio2video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="957da6c3-7cbb-441f-acd1-e738c018e0e1", api_key=api_key)
    
    def predictions(self, audio: Union[MediaFile, str, bytes], image: Union[MediaFile, str, bytes], **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio: Audio file
            
            image: Grayscale input image
            
        """
        return self.submit_job("/predictions", audio=audio, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class stablelm_tuned_alpha_7b(FastClient):
    """
    Generated client for stability-ai/stablelm-tuned-alpha-7b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c89dcbf6-be34-479b-8aa5-d5d6486bec1a", api_key=api_key)
    
    def predictions(self, top_p: float = 1.0, prompt: str = "What's your mood today?", temperature: float = 0.75, max_new_tokens: int = 100, repetition_penalty: float = 1.2, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            top_p: Valid if you choose top_p decoding. When decoding text, samples from the top p percentage of most likely tokens; lower to ignore less likely tokens Defaults to 1.0.
            
            prompt: Input Prompt. Defaults to "What's your mood today?".
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic, 0.75 is a good starting value. Defaults to 0.75.
            
            max_new_tokens: Maximum number of tokens to generate. A word is generally 2-3 tokens Defaults to 100.
            
            repetition_penalty: Penalty for repeated words in generated text; 1 is no penalty, values greater than 1 discourage repetition, less than 1 encourage it. Defaults to 1.2.
            
        """
        return self.submit_job("/predictions", top_p=top_p, prompt=prompt, temperature=temperature, max_new_tokens=max_new_tokens, repetition_penalty=repetition_penalty, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class disco_diffusion(FastClient):
    """
    Generated client for nightmareai/disco-diffusion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="13f90460-6633-4462-a937-e8162594b24b", api_key=api_key)
    
    def predictions(self, _50: bool = True, _101: bool = False, steps: int = 100, width: int = 1280, _50x4: bool = False, i_16: bool = True, i_32: bool = True, i_14: bool = False, height: int = 768, prompt: str = 'A beautiful painting of a singular lighthouse, shining its light across a tumultuous sea of blood by greg rutkowski and thomas kinkade, Trending on artstation.', _50x16: bool = False, _50x64: bool = False, _50x101: bool = False, tv_scale: int = 0, sat_scale: int = 0, skip_augs: bool = False, _50_cc12m: bool = False, i_14_336: bool = False, init_scale: int = 1000, skip_steps: int = 10, range_scale: int = 150, cutn_batches: int = 4, display_rate: int = 20, target_scale: int = 20000, _101_yfcc15m: bool = False, _50_yffcc15m: bool = False, diffusion_model: str = '512x512_diffusion_uncond_finetune_008100', i_32_laion2b_e16: bool = False, clip_guidance_scale: int = 5000, use_secondary_model: bool = True, _50_quickgelu_cc12m: bool = False, i_16_laion400m_e31: bool = False, i_16_laion400m_e32: bool = False, i_32_laion400m_e31: bool = False, i_32_laion400m_e32: bool = False, _50_quickgelu_yfcc15m: bool = False, _101_quickgelu_yfcc15m: bool = False, diffusion_sampling_mode: str = 'ddim', i_32quickgelu_laion400m_e31: bool = False, i_32quickgelu_laion400m_e32: bool = False, seed: Optional[int] = None, init_image: Optional[Union[MediaFile, str, bytes]] = None, target_image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            _50: Use RN50 model Defaults to True.
            
            _101: Use RN101 model Defaults to False.
            
            steps: Number of steps, higher numbers will give more refined output but will take longer Defaults to 100.
            
            width: Width of the output image, higher numbers will take longer Defaults to 1280.
            
            _50x4: Use RN50x4 model Defaults to False.
            
            i_16: Use ViTB16 model Defaults to True.
            
            i_32: Use ViTB32 model Defaults to True.
            
            i_14: Use ViTB14 model Defaults to False.
            
            height: Height of the output image, higher numbers will take longer Defaults to 768.
            
            prompt: Text Prompt Defaults to 'A beautiful painting of a singular lighthouse, shining its light across a tumultuous sea of blood by greg rutkowski and thomas kinkade, Trending on artstation.'.
            
            _50x16: Use RN50x16 model Defaults to False.
            
            _50x64: Use RN50x64 model Defaults to False.
            
            _50x101: Use RN50x101 model Defaults to False.
            
            tv_scale: TV Scale Defaults to 0.
            
            sat_scale: Saturation Scale Defaults to 0.
            
            skip_augs: Skip Augmentations Defaults to False.
            
            _50_cc12m: Use RN50_cc12m model Defaults to False.
            
            i_14_336: Use ViTL14_336 model Defaults to False.
            
            init_scale: Initial Scale Defaults to 1000.
            
            skip_steps: Skip Steps Defaults to 10.
            
            range_scale: Range Scale Defaults to 150.
            
            cutn_batches: Cut Batches Defaults to 4.
            
            display_rate: Steps between outputs, lower numbers may slow down generation. Defaults to 20.
            
            target_scale: Target Scale Defaults to 20000.
            
            _101_yfcc15m: Use RN101_yfcc15m model Defaults to False.
            
            _50_yffcc15m: Use RN50_yffcc15m model Defaults to False.
            
            diffusion_model: Diffusion Model Defaults to '512x512_diffusion_uncond_finetune_008100'.
            
            i_32_laion2b_e16: Use ViTB32_laion2b_e16 model Defaults to False.
            
            clip_guidance_scale: CLIP Guidance Scale Defaults to 5000.
            
            use_secondary_model: Use secondary model Defaults to True.
            
            _50_quickgelu_cc12m: Use RN50_quickgelu_cc12m model Defaults to False.
            
            i_16_laion400m_e31: Use ViTB16_laion400m_e31 model Defaults to False.
            
            i_16_laion400m_e32: Use ViTB16_laion400m_e32 model Defaults to False.
            
            i_32_laion400m_e31: Use ViTB32_laion400m_e31 model Defaults to False.
            
            i_32_laion400m_e32: Use ViTB32_laion400m_e32 model Defaults to False.
            
            _50_quickgelu_yfcc15m: Use RN50_quickgelu_yfcc15m model Defaults to False.
            
            _101_quickgelu_yfcc15m: Use RN101_quickgelu_yfcc15m model Defaults to False.
            
            diffusion_sampling_mode: Diffusion Sampling Mode Defaults to 'ddim'.
            
            i_32quickgelu_laion400m_e31: Use ViTB32quickgelu_laion400m_e31 model Defaults to False.
            
            i_32quickgelu_laion400m_e32: Use ViTB32quickgelu_laion400m_e32 model Defaults to False.
            
            seed: Seed (leave empty to use a random seed) Optional.
            
            init_image: Initial image to start generation from Optional.
            
            target_image: Target image to generate towards, similarly to the text prompt Optional.
            
        """
        return self.submit_job("/predictions", _50=_50, _101=_101, steps=steps, width=width, _50x4=_50x4, i_16=i_16, i_32=i_32, i_14=i_14, height=height, prompt=prompt, _50x16=_50x16, _50x64=_50x64, _50x101=_50x101, tv_scale=tv_scale, sat_scale=sat_scale, skip_augs=skip_augs, _50_cc12m=_50_cc12m, i_14_336=i_14_336, init_scale=init_scale, skip_steps=skip_steps, range_scale=range_scale, cutn_batches=cutn_batches, display_rate=display_rate, target_scale=target_scale, _101_yfcc15m=_101_yfcc15m, _50_yffcc15m=_50_yffcc15m, diffusion_model=diffusion_model, i_32_laion2b_e16=i_32_laion2b_e16, clip_guidance_scale=clip_guidance_scale, use_secondary_model=use_secondary_model, _50_quickgelu_cc12m=_50_quickgelu_cc12m, i_16_laion400m_e31=i_16_laion400m_e31, i_16_laion400m_e32=i_16_laion400m_e32, i_32_laion400m_e31=i_32_laion400m_e31, i_32_laion400m_e32=i_32_laion400m_e32, _50_quickgelu_yfcc15m=_50_quickgelu_yfcc15m, _101_quickgelu_yfcc15m=_101_quickgelu_yfcc15m, diffusion_sampling_mode=diffusion_sampling_mode, i_32quickgelu_laion400m_e31=i_32quickgelu_laion400m_e31, i_32quickgelu_laion400m_e32=i_32quickgelu_laion400m_e32, seed=seed, init_image=init_image, target_image=target_image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class grounded_sam(FastClient):
    """
    Generated client for schananas/grounded-sam
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2312e3fb-6a3e-4d7c-b0b6-6f145b0c721f", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes] = 'https://st.mngbcn.com/rcs/pics/static/T5/fotos/outfit/S20/57034757_56-99999999_01.jpg', mask_prompt: str = 'clothes,shoes', adjustment_factor: int = 0, negative_mask_prompt: str = 'pants', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Image Defaults to 'https://st.mngbcn.com/rcs/pics/static/T5/fotos/outfit/S20/57034757_56-99999999_01.jpg'.
            
            mask_prompt: Positive mask prompt Defaults to 'clothes,shoes'.
            
            adjustment_factor: Mask Adjustment Factor (-ve for erosion, +ve for dilation) Defaults to 0.
            
            negative_mask_prompt: Negative mask prompt Defaults to 'pants'.
            
        """
        return self.submit_job("/predictions", image=image, mask_prompt=mask_prompt, adjustment_factor=adjustment_factor, negative_mask_prompt=negative_mask_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class parakeet_rnnt_1_1b(FastClient):
    """
    Generated client for nvidia/parakeet-rnnt-1-1b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="5a2f2250-0001-4849-b676-828f107dfc70", api_key=api_key)
    
    def predictions(self, audio_file: Union[MediaFile, str, bytes], **kwargs) -> APISeex:
        """
        
        
        
        Args:
            audio_file: Input audio file to be transcribed by the ASR model
            
        """
        return self.submit_job("/predictions", audio_file=audio_file, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class flux_1_dev(FastClient):
    """
    Generated client for prunaai/flux-1-dev
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="96ed92a8-4291-46d7-a9d2-2827df0a69c7", api_key=api_key)
    
    def predictions(self, prompt: str, seed: int = -1, guidance: float = 7.5, image_size: int = 1024, speed_mode: str = 'Juiced 🔥 (default)', aspect_ratio: str = '1:1', output_format: str = 'png', output_quality: int = 80, num_inference_steps: int = 28, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt
            
            seed: Seed Defaults to -1.
            
            guidance: Guidance scale Defaults to 7.5.
            
            image_size: Base image size (longest side) Defaults to 1024.
            
            speed_mode: Speed optimization level Defaults to 'Juiced 🔥 (default)'.
            
            aspect_ratio: Aspect ratio of the output image Defaults to '1:1'.
            
            output_format: Output format Defaults to 'png'.
            
            output_quality: Output quality (for jpg and webp) Defaults to 80.
            
            num_inference_steps: Number of inference steps Defaults to 28.
            
        """
        return self.submit_job("/predictions", prompt=prompt, seed=seed, guidance=guidance, image_size=image_size, speed_mode=speed_mode, aspect_ratio=aspect_ratio, output_format=output_format, output_quality=output_quality, num_inference_steps=num_inference_steps, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class sana(FastClient):
    """
    Generated client for nvidia/sana
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="392df87f-336a-4d25-b0a1-ab03dec6a36a", api_key=api_key)
    
    def predictions(self, width: int = 1024, height: int = 1024, prompt: str = 'a cyberpunk cat with a neon sign that says "Sana"', model_variant: str = '1600M-1024px', guidance_scale: float = 5.0, negative_prompt: str = '', pag_guidance_scale: float = 2.0, num_inference_steps: int = 18, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image Defaults to 1024.
            
            height: Height of output image Defaults to 1024.
            
            prompt: Input prompt Defaults to 'a cyberpunk cat with a neon sign that says "Sana"'.
            
            model_variant: Model variant. 1600M variants are slower but produce higher quality than 600M, 1024px variants are optimized for 1024x1024px images, 512px variants are optimized for 512x512px images, 'multilang' variants can be prompted in both English and Chinese Defaults to '1600M-1024px'.
            
            guidance_scale: Classifier-free guidance scale Defaults to 5.0.
            
            negative_prompt: Specify things to not see in the output Defaults to ''.
            
            pag_guidance_scale: PAG Guidance scale Defaults to 2.0.
            
            num_inference_steps: Number of denoising steps Defaults to 18.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, model_variant=model_variant, guidance_scale=guidance_scale, negative_prompt=negative_prompt, pag_guidance_scale=pag_guidance_scale, num_inference_steps=num_inference_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class controlnet_preprocessors(FastClient):
    """
    Generated client for fofr/controlnet-preprocessors
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="09029b7d-3fcc-42b6-b142-6839f9745612", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], hed: bool = True, sam: bool = True, mlsd: bool = True, pidi: bool = True, canny: bool = True, leres: bool = True, midas: bool = True, content: bool = True, lineart: bool = True, open_pose: bool = True, normal_bae: bool = True, face_detector: bool = True, lineart_anime: bool = True, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Image to preprocess
            
            hed: Run HED detection Defaults to True.
            
            sam: Run Sam detection Defaults to True.
            
            mlsd: Run MLSD detection Defaults to True.
            
            pidi: Run PidiNet detection Defaults to True.
            
            canny: Run canny edge detection Defaults to True.
            
            leres: Run Leres detection Defaults to True.
            
            midas: Run Midas detection Defaults to True.
            
            content: Run content shuffle detection Defaults to True.
            
            lineart: Run Lineart detection Defaults to True.
            
            open_pose: Run Openpose detection Defaults to True.
            
            normal_bae: Run NormalBae detection Defaults to True.
            
            face_detector: Run face detection Defaults to True.
            
            lineart_anime: Run LineartAnime detection Defaults to True.
            
        """
        return self.submit_job("/predictions", image=image, hed=hed, sam=sam, mlsd=mlsd, pidi=pidi, canny=canny, leres=leres, midas=midas, content=content, lineart=lineart, open_pose=open_pose, normal_bae=normal_bae, face_detector=face_detector, lineart_anime=lineart_anime, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.nvidia.parakeet_rnnt_1_1b import parakeet_rnnt_1_1b
from socaity.sdk.replicate.nvidia.sana import sana
from socaity.sdk.replicate.nvidia.sana_sprint_1_6b import sana_sprint_1_6b


from fastsdk import FastClient, APISeex
from typing import List, Union, Any, Dict

from media_toolkit import ImageFile, MediaFile, VideoFile


class face2face(FastClient):
    """
    Swap faces from images and videos. Create face embeddings.
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0d69b27a-f893-4582-b3e8-a18c1f588e90", api_key=api_key)
    
    def swap(self, faces: Union[MediaFile, Any, str, Dict[str, Any], List[Any], bytes], media: Union[MediaFile, Any, str, VideoFile, ImageFile, bytes], enhance_face_model: str = 'gpen_bfr_512', **kwargs) -> APISeex:
        """
        Swap faces in an image or video.
        
        Args:
            faces: The face(s) to swap to. Can be:
                - str: Name of a reference face
                - dict: Swap pairs with structure {source_face_name: target_face_name}
                - list: List of face names or Face embeddings
                - MediaFile: Single face embedding file
                - MediaList: Multiple face embedding files
            media: The image or video to swap faces in
            enhance_face_model: Face enhancement model to use. Defaults to 'gpen_bfr_512'
        
        Returns:
            Union[ImageFile, VideoFile]: The resulting media with swapped faces
        
        Raises:
            ValueError: If no faces are provided or media type is unsupported
        
        """
        return self.submit_job("/swap", faces=faces, media=media, enhance_face_model=enhance_face_model, **kwargs)
    
    def add_face(self, image: Union[ImageFile, Any, MediaFile, str, bytes], face_name: Union[List[Any], str], save: bool = False, **kwargs) -> APISeex:
        """
        Add one or multiple reference face(s) to the face swapper.
        
        Args:
            face_name: Name(s) for the reference face(s).
                - If a single string, creates one face embedding
                - If a list of strings, creates embeddings for each face from left to right in the image
            image: The image from which to extract the face(s).
                - ImageFile: Standard image file
            save: Whether to save the face embeddings to disk.
                Note: This is controlled by ALLOW_EMBEDDING_SAVE_ON_SERVER setting
        
        Returns:
            Union[MediaFile, MediaDict]:
                - For single face: MediaFile containing the face embedding
                - For multiple faces: MediaDict mapping face names to their embeddings
        
        Raises:
            ValueError: If no face name is provided or no faces are detected in the image
        
        """
        return self.submit_job("/add-face", image=image, face_name=face_name, save=save, **kwargs)
    
    def swap_video(self, faces: Union[MediaFile, Any, str, Dict[str, Any], List[Any], bytes], target_video: Union[VideoFile, Any, MediaFile, str, bytes], include_audio: bool = True, enhance_face_model: str = 'gpen_bfr_512', **kwargs) -> APISeex:
        """
        Swap faces in a video file.
        
        Args:
            face_name: The face(s) to swap to. Can be:
                - str: Name of a reference face
                - list: List of face names or Face objects
                - MediaFile: Single face embedding file
                - MediaList: Multiple face embedding files
            target_video: The video to swap faces in
            include_audio: Whether to include audio in the output video
            enhance_face_model: Face enhancement model to use. Defaults to 'gpen_bfr_512'
        
        Returns:
            VideoFile: The resulting video with swapped faces
        
        Raises:
            ValueError: If no faces are provided or video cannot be processed
        
        """
        return self.submit_job("/swap-video", faces=faces, target_video=target_video, include_audio=include_audio, enhance_face_model=enhance_face_model, **kwargs)
    
    def swap_img_to_img(self, source_img: Union[ImageFile, Any, MediaFile, str, bytes], target_img: Union[ImageFile, Any, MediaFile, str, bytes], enhance_face_model: str = 'gpen_bfr_512', **kwargs) -> APISeex:
        """
        Swap faces between two images.
        
        Args:
            source_img: Source image containing the face(s) to swap from
            target_img: Target image containing the face(s) to swap to
            enhance_face_model: Face enhancement model to use. Defaults to 'gpen_bfr_512'
        
        Returns:
            ImageFile: The resulting image with swapped faces
        
        """
        return self.submit_job("/swap-img-to-img", source_img=source_img, target_img=target_img, enhance_face_model=enhance_face_model, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = swap
    __call__ = swap


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class ltx_video(FastClient):
    """
    Generated client for lightricks/ltx-video
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ed68a927-b15b-4d1e-aa2c-cc9e968152e5", api_key=api_key)
    
    def predictions(self, cfg: float = 3.0, model: str = '0.9.1', steps: int = 30, length: int = 97, prompt: str = 'best quality, 4k, HDR, a tracking shot of a beautiful scene', target_size: int = 640, aspect_ratio: str = '3:2', negative_prompt: str = 'low quality, worst quality, deformed, distorted', image_noise_scale: float = 0.15, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            cfg: How strongly the video follows the prompt Defaults to 3.0.
            
            model: Model version to use Defaults to '0.9.1'.
            
            steps: Number of steps Defaults to 30.
            
            length: Length of the output video in frames Defaults to 97.
            
            prompt: Text prompt for the video. This model needs long descriptive prompts, if the prompt is too short the quality won't be good. Defaults to 'best quality, 4k, HDR, a tracking shot of a beautiful scene'.
            
            target_size: Target size for the output video Defaults to 640.
            
            aspect_ratio: Aspect ratio of the output video. Ignored if an image is provided. Defaults to '3:2'.
            
            negative_prompt: Things you do not want to see in your video Defaults to 'low quality, worst quality, deformed, distorted'.
            
            image_noise_scale: Lower numbers stick more closely to the input image Defaults to 0.15.
            
            seed: Set a seed for reproducibility. Random by default. Optional.
            
            image: Optional input image to use as the starting frame Optional.
            
        """
        return self.submit_job("/predictions", cfg=cfg, model=model, steps=steps, length=length, prompt=prompt, target_size=target_size, aspect_ratio=aspect_ratio, negative_prompt=negative_prompt, image_noise_scale=image_noise_scale, seed=seed, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class spanish_f5_tts(FastClient):
    """
    Generated client for fermatresearch/spanish-f5-tts
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="49bd6dea-f24a-4f9f-b32d-61610d872d20", api_key=api_key)
    
    def predictions(self, gen_text: str, ref_text: str, ref_audio: Union[MediaFile, str, bytes], remove_silence: bool = True, custom_split_words: str = '', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            gen_text: Text to Generate
            
            ref_text: Reference Text
            
            ref_audio: Reference audio for voice cloning
            
            remove_silence: Automatically remove silences? Defaults to True.
            
            custom_split_words: Custom split words, comma separated Defaults to ''.
            
        """
        return self.submit_job("/predictions", gen_text=gen_text, ref_text=ref_text, ref_audio=ref_audio, remove_silence=remove_silence, custom_split_words=custom_split_words, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.datacte.flux_aesthetic_anime import flux_aesthetic_anime
from socaity.sdk.replicate.datacte.flux_synthetic_anime import flux_synthetic_anime
from socaity.sdk.replicate.datacte.proteus_v0_2 import proteus_v0_2
from socaity.sdk.replicate.datacte.proteus_v0_3 import proteus_v0_3


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class real_basicvsr_video_superresolution(FastClient):
    """
    Generated client for pollinations/real-basicvsr-video-superresolution
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="b901d4ed-734c-4961-9873-121a55ff9ce1", api_key=api_key)
    
    def predictions(self, video: Union[MediaFile, str, bytes], **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video: input video
            
        """
        return self.submit_job("/predictions", video=video, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class video_split(FastClient):
    """
    Generated client for lucataco/video-split
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="c51c85bb-b396-4089-84a5-3a706c8e8756", api_key=api_key)
    
    def predictions(self, input_video: Union[MediaFile, str, bytes], target_fps: int = 30, target_width: int = 848, target_height: int = 480, create_captions: bool = False, target_duration: float = 2.0, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_video: Input video file (MP4 or MOV)
            
            target_fps: Target FPS for each segment Defaults to 30.
            
            target_width: Target width for each segment Defaults to 848.
            
            target_height: Target height for each segment Defaults to 480.
            
            create_captions: Create empty caption files for each segment Defaults to False.
            
            target_duration: Target duration for each segment in seconds Defaults to 2.0.
            
        """
        return self.submit_job("/predictions", input_video=input_video, target_fps=target_fps, target_width=target_width, target_height=target_height, create_captions=create_captions, target_duration=target_duration, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class csm_1b(FastClient):
    """
    Generated client for lucataco/csm-1b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="a81aae22-ba41-4ed6-9a84-8cf99c8e3779", api_key=api_key)
    
    def predictions(self, text: str = 'Hello from Sesame.', speaker: int = 0, max_audio_length_ms: int = 10000, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Text to convert to speech Defaults to 'Hello from Sesame.'.
            
            speaker: Speaker ID (0 or 1) Defaults to 0.
            
            max_audio_length_ms: Maximum audio length in milliseconds Defaults to 10000.
            
        """
        return self.submit_job("/predictions", text=text, speaker=speaker, max_audio_length_ms=max_audio_length_ms, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.stability_ai.sdxl import sdxl
from socaity.sdk.replicate.stability_ai.stable_diffusion import stable_diffusion
from socaity.sdk.replicate.stability_ai.stable_diffusion_inpainting import stable_diffusion_inpainting
from socaity.sdk.replicate.stability_ai.stablelm_tuned_alpha_7b import stablelm_tuned_alpha_7b


from fastsdk import FastClient, APISeex

class phi_2(FastClient):
    """
    Generated client for lucataco/phi-2
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ce54bb7f-20cf-46b6-94bd-b83766b62268", api_key=api_key)
    
    def predictions(self, prompt: str, max_length: int = 200, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            prompt: Input prompt
            
            max_length: Max length Defaults to 200.
            
        """
        return self.submit_job("/predictions", prompt=prompt, max_length=max_length, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class mask_maker(FastClient):
    """
    Generated client for jweek/mask-maker
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="d1b3584b-c64d-4a9d-9a4a-539921f667e4", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], threshold: float = 0.2, mask_format: str = 'coco_rle', mask_output: str = '', mask_prompt: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image file path or URL
            
            threshold: Confidence level for object detection Defaults to 0.2.
            
            mask_format: RLE encoding format for masks. 'coco_rle' (default) or 'custom_rle' Defaults to 'coco_rle'.
            
            mask_output: Single-line DSL defining composite masks (overrides default one-per-term).  Infix operators (left-to-right):    `&` → AND,  `|` or `+` → OR,  `A - B` → A AND NOT(B),  `-term` → NOT(term),  `XOR`.  Example: 'rider: man + horse; dog: dog' Defaults to ''.
            
            mask_prompt: Comma-separated names of the objects to be detected Optional.
            
        """
        return self.submit_job("/predictions", image=image, threshold=threshold, mask_format=mask_format, mask_output=mask_output, mask_prompt=mask_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class bge_1_5_query_embeddings(FastClient):
    """
    Generated client for center-for-curriculum-redesign/bge-1-5-query-embeddings
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0b47f390-cedf-429d-9157-dada4f0b747a", api_key=api_key)
    
    def predictions(self, normalize: bool = True, precision: str = 'full', query_texts: str = '[]', batchtoken_max: float = 200.0, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            normalize: normalizes returned embedding vectors to a magnitude of 1. (default: true, as this model presumes cosine similarity comparisons downstream) Defaults to True.
            
            precision: numerical precision for inference computations. Either full or half. Defaults to a paranoid value of full. You may want to test if 'half' is sufficient for your needs, though regardless you should probably prefer to use the same precision for querying as you do for archiving. Defaults to 'full'.
            
            query_texts: A serialized JSON array of strings you wish to generate *retreival* embeddings for. (note, that you should keep this list short to avoid Replicate response size limitations). Use this to embed short text queries intended for comparison against document text. A vector will be returned corresponding to each line of text in the input array (in order of input). This endpoint will automatically format your query strings for retrieval, you do not need to preprocess them. Defaults to '[]'.
            
            batchtoken_max: You probably don't need to worry about this parameter if you're just getting the embeddings for a handful of queries. This parameter sets the maximumum number of kibiTokens (1 kibiToken = 1024 tokens) to try to stuff into a batch (to avoid out of memory errors but maximize throughput). If the total number of tokens across the flattened list of requested embeddings exceed this value, the list will be split internally and run across multiple forward passes. This will not affect the shape of your output, just the time it takes to run. Defaults to 200.0.
            
        """
        return self.submit_job("/predictions", normalize=normalize, precision=precision, query_texts=query_texts, batchtoken_max=batchtoken_max, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class singing_voice_conversion(FastClient):
    """
    Generated client for lucataco/singing-voice-conversion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="03f4b34b-cd6d-425d-a9b3-6272ae4cb4df", api_key=api_key)
    
    def predictions(self, source_audio: Union[MediaFile, str, bytes], target_singer: str = 'Taylor Swift', key_shift_mode: int = 0, pitch_shift_control: str = 'Auto Shift', diffusion_inference_steps: int = 1000, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            source_audio: Input source audio file
            
            target_singer: Target singer to convert audio to Defaults to 'Taylor Swift'.
            
            key_shift_mode: Key shift values Defaults to 0.
            
            pitch_shift_control: Pitch shift control Defaults to 'Auto Shift'.
            
            diffusion_inference_steps: Diffusion inference steps Defaults to 1000.
            
        """
        return self.submit_job("/predictions", source_audio=source_audio, target_singer=target_singer, key_shift_mode=key_shift_mode, pitch_shift_control=pitch_shift_control, diffusion_inference_steps=diffusion_inference_steps, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class animate_diff(FastClient):
    """
    Generated client for lucataco/animate-diff
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="701a8b9d-7d39-433d-bde2-8bcc483e09a3", api_key=api_key)
    
    def predictions(self, path: str = 'toonyou_beta3.safetensors', steps: int = 25, prompt: str = 'masterpiece, best quality, 1girl, solo, cherry blossoms, hanami, pink flower, white flower, spring season, wisteria, petals, flower, plum blossoms, outdoors, falling petals, white hair, black eyes', n_prompt: str = '', motion_module: str = 'mm_sd_v14', guidance_scale: float = 7.5, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            path: Select a Module Defaults to 'toonyou_beta3.safetensors'.
            
            steps: Number of inference steps Defaults to 25.
            
            prompt: Input prompt Defaults to 'masterpiece, best quality, 1girl, solo, cherry blossoms, hanami, pink flower, white flower, spring season, wisteria, petals, flower, plum blossoms, outdoors, falling petals, white hair, black eyes'.
            
            n_prompt: Negative prompt Defaults to ''.
            
            motion_module: Select a Motion Model Defaults to 'mm_sd_v14'.
            
            guidance_scale: guidance scale Defaults to 7.5.
            
            seed: Seed (0 = random, maximum: 2147483647) Optional.
            
        """
        return self.submit_job("/predictions", path=path, steps=steps, prompt=prompt, n_prompt=n_prompt, motion_module=motion_module, guidance_scale=guidance_scale, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class real_esrgan(FastClient):
    """
    Generated client for nightmareai/real-esrgan
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f002d550-9af6-4fe1-99f9-26f2bccbad1f", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], scale: float = 4.0, face_enhance: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            scale: Factor to scale image by Defaults to 4.0.
            
            face_enhance: Run GFPGAN face enhancement along with upscaling Defaults to False.
            
        """
        return self.submit_job("/predictions", image=image, scale=scale, face_enhance=face_enhance, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class invsr(FastClient):
    """
    Generated client for zsyoaoa/invsr
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="3f8ab2b7-4850-4932-b8cd-ae93251d4ed0", api_key=api_key)
    
    def predictions(self, in_path: Union[MediaFile, str, bytes], seed: int = 12345, num_steps: int = 1, chopping_size: int = 128, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            in_path: Input low-quality image
            
            seed: Random seed. Leave blank to randomize the seed. Defaults to 12345.
            
            num_steps: Number of sampling steps. Defaults to 1.
            
            chopping_size: Chopping resolution Defaults to 128.
            
        """
        return self.submit_job("/predictions", in_path=in_path, seed=seed, num_steps=num_steps, chopping_size=chopping_size, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class controlnet_tile(FastClient):
    """
    Generated client for lucataco/controlnet-tile
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="5bf66383-8a5d-4cec-9d37-3f9fe24288a8", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], scale: int = 2, strength: float = 0.5, num_inference_steps: int = 32, seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Input image
            
            scale: Scale multiplier Defaults to 2.
            
            strength: Strength of the diffusion Defaults to 0.5.
            
            num_inference_steps: Number of inference steps Defaults to 32.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", image=image, scale=scale, strength=strength, num_inference_steps=num_inference_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class neon_tts(FastClient):
    """
    Generated client for awerks/neon-tts
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="402dbd40-c083-44ca-b892-db9c53a2b54e", api_key=api_key)
    
    def predictions(self, text: str, language: str = 'en', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Input text for Text-to-Speech conversion
            
            language: Language of the text Defaults to 'en'.
            
        """
        return self.submit_job("/predictions", text=text, language=language, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class ssd_1b(FastClient):
    """
    Generated client for lucataco/ssd-1b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="7fe791ac-9587-4813-9c0d-857e2ecfbf47", api_key=api_key)
    
    def predictions(self, width: int = 768, height: int = 768, prompt: str = 'with smoke, half ice and half fire and ultra realistic in detail.wolf, typography, dark fantasy, wildlife photography, vibrant, cinematic and on a black background', scheduler: str = 'K_EULER', lora_scale: float = 0.6, num_outputs: int = 1, batched_prompt: bool = False, guidance_scale: float = 7.5, apply_watermark: bool = True, negative_prompt: str = 'scary, cartoon, painting', prompt_strength: float = 0.8, num_inference_steps: int = 25, disable_safety_checker: bool = False, mask: Optional[Union[MediaFile, str, bytes]] = None, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, replicate_weights: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image Defaults to 768.
            
            height: Height of output image Defaults to 768.
            
            prompt: Input prompt Defaults to 'with smoke, half ice and half fire and ultra realistic in detail.wolf, typography, dark fantasy, wildlife photography, vibrant, cinematic and on a black background'.
            
            scheduler: scheduler Defaults to 'K_EULER'.
            
            lora_scale: LoRA additive scale. Only applicable on trained models. Defaults to 0.6.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            batched_prompt: When active, your prompt will be split by newlines and images will be generated for each individual line Defaults to False.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            apply_watermark: Applies a watermark to enable determining if an image is generated in downstream applications. If you have other provisions for generating or deploying images safely, you can use this to disable watermarking. Defaults to True.
            
            negative_prompt: Negative Input prompt Defaults to 'scary, cartoon, painting'.
            
            prompt_strength: Prompt strength when using img2img / inpaint. 1.0 corresponds to full destruction of information in image Defaults to 0.8.
            
            num_inference_steps: Number of denoising steps Defaults to 25.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API. See https://replicate.com/docs/how-does-replicate-work#safety Defaults to False.
            
            mask: Input mask for inpaint mode. Black areas will be preserved, white areas will be inpainted. Optional.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for img2img or inpaint mode Optional.
            
            replicate_weights: Replicate LoRA weights to use. Leave blank to use the default weights. Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, scheduler=scheduler, lora_scale=lora_scale, num_outputs=num_outputs, batched_prompt=batched_prompt, guidance_scale=guidance_scale, apply_watermark=apply_watermark, negative_prompt=negative_prompt, prompt_strength=prompt_strength, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, mask=mask, seed=seed, image=image, replicate_weights=replicate_weights, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Optional


class stable_diffusion_videos(FastClient):
    """
    Generated client for nateraw/stable-diffusion-videos
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="bfe0fe2b-a359-449c-8ae4-acc8fb4bb82c", api_key=api_key)
    
    def predictions(self, fps: int = 15, prompts: str = 'a cat | a dog | a horse', num_steps: int = 50, scheduler: str = 'klms', guidance_scale: float = 7.5, num_inference_steps: int = 50, seeds: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            fps: Frame rate for the video. Defaults to 15.
            
            prompts: Input prompts, separate each prompt with '|'. Defaults to 'a cat | a dog | a horse'.
            
            num_steps: Steps for generating the interpolation video. Recommended to set to 3 or 5 for testing, then up it to 60-200 for better results. Defaults to 50.
            
            scheduler: Choose the scheduler Defaults to 'klms'.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 7.5.
            
            num_inference_steps: Number of denoising steps for each image generated from the prompt Defaults to 50.
            
            seeds: Random seed, separated with '|' to use different seeds for each of the prompt provided above. Leave blank to randomize the seed. Optional.
            
        """
        return self.submit_job("/predictions", fps=fps, prompts=prompts, num_steps=num_steps, scheduler=scheduler, guidance_scale=guidance_scale, num_inference_steps=num_inference_steps, seeds=seeds, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class video_background_remover_appender(FastClient):
    """
    Generated client for tahercoolguy/video-background-remover-appender
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="360e4917-ea74-4b91-98e8-7ba010b0151d", api_key=api_key)
    
    def predictions(self, input_video: Union[MediaFile, str, bytes], fps: int = 0, color: str = '#00FF00', bg_mode: str = 'cover', bg_type: str = 'Color', video_handling: str = 'loop', bg_image: Optional[Union[MediaFile, str, bytes]] = None, bg_video: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_video: Input video
            
            fps: Output FPS Defaults to 0.
            
            color: Background Color Defaults to '#00FF00'.
            
            bg_mode: Background Mode Defaults to 'cover'.
            
            bg_type: Background Type Defaults to 'Color'.
            
            video_handling: Video Handling Defaults to 'loop'.
            
            bg_image: Background Image Optional.
            
            bg_video: Background Video Optional.
            
        """
        return self.submit_job("/predictions", input_video=input_video, fps=fps, color=color, bg_mode=bg_mode, bg_type=bg_type, video_handling=video_handling, bg_image=bg_image, bg_video=bg_video, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class clip_embeddings(FastClient):
    """
    Generated client for krthr/clip-embeddings
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="32a10c5e-4802-46b1-8928-c4c78a1b294e", api_key=api_key)
    
    def predictions(self, text: Optional[str] = None, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            text: Input text Optional.
            
            image: Input image Optional.
            
        """
        return self.submit_job("/predictions", text=text, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class llama_7b(FastClient):
    """
    Generated client for replicate/llama-7b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="dd6af761-d6b9-4a08-990d-2869397a679c", api_key=api_key)
    
    def predictions(self, prompt: str, top_p: float = 0.95, max_gen_len: int = 256, temperature: float = 0.8, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Text to prefix with 'hello '
            
            top_p: Top p value Defaults to 0.95.
            
            max_gen_len: Max generation length Defaults to 256.
            
            temperature: Temperature Defaults to 0.8.
            
        """
        return self.submit_job("/predictions", prompt=prompt, top_p=top_p, max_gen_len=max_gen_len, temperature=temperature, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.openai.gpt_4_1 import gpt_4_1
from socaity.sdk.replicate.openai.gpt_4_1_mini import gpt_4_1_mini
from socaity.sdk.replicate.openai.gpt_4_1_nano import gpt_4_1_nano
from socaity.sdk.replicate.openai.gpt_4o import gpt_4o
from socaity.sdk.replicate.openai.gpt_4o_mini import gpt_4o_mini
from socaity.sdk.replicate.openai.o1 import o1
from socaity.sdk.replicate.openai.o1_mini import o1_mini
from socaity.sdk.replicate.openai.whisper import whisper


from fastsdk import FastClient, APISeex
from typing import Optional


class deforum_stable_diffusion(FastClient):
    """
    Generated client for deforum/deforum-stable-diffusion
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="2fd42d79-f34b-4c62-ac88-61c3ca7998b3", api_key=api_key)
    
    def predictions(self, fps: int = 15, zoom: str = '0: (1.04)', angle: str = '0:(0)', sampler: str = 'plms', max_frames: int = 100, translation_x: str = '0: (0)', translation_y: str = '0: (0)', color_coherence: str = 'Match Frame 0 LAB', animation_prompts: str = '0: a beautiful portrait of a woman by Artgerm, trending on Artstation', seed: Optional[int] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            fps: Choose fps for the video. Defaults to 15.
            
            zoom: zoom parameter for the motion Defaults to '0: (1.04)'.
            
            angle: angle parameter for the motion Defaults to '0:(0)'.
            
            sampler: sampler Defaults to 'plms'.
            
            max_frames: Number of frames for animation Defaults to 100.
            
            translation_x: translation_x parameter for the motion Defaults to '0: (0)'.
            
            translation_y: translation_y parameter for the motion Defaults to '0: (0)'.
            
            color_coherence: color_coherence Defaults to 'Match Frame 0 LAB'.
            
            animation_prompts: Prompt for animation. Provide 'frame number : prompt at this frame', separate different prompts with '|'. Make sure the frame number does not exceed the max_frames. Defaults to '0: a beautiful portrait of a woman by Artgerm, trending on Artstation'.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", fps=fps, zoom=zoom, angle=angle, sampler=sampler, max_frames=max_frames, translation_x=translation_x, translation_y=translation_y, color_coherence=color_coherence, animation_prompts=animation_prompts, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class hcflow_sr(FastClient):
    """
    Generated client for jingyunliang/hcflow-sr
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="df7f6d61-85a1-44a9-a3f6-4f997f3da1d5", api_key=api_key)
    
    def predictions(self, image: Union[MediaFile, str, bytes], model_type: str = 'celeb', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            image: Low resolution image
            
            model_type: celeb photo or general image Defaults to 'celeb'.
            
        """
        return self.submit_job("/predictions", image=image, model_type=model_type, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class video_utils(FastClient):
    """
    Generated client for nicolascoutureau/video-utils
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ff5b0116-92a4-490c-9d7c-6f64b1092882", api_key=api_key)
    
    def predictions(self, task: str, input_file: Union[MediaFile, str, bytes], fps: int = 0, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            task: Task to perform
            
            input_file: File – zip, image or video to process
            
            fps: frames per second, if relevant. Use 0 to keep original fps (or use default). Converting to GIF defaults to 12fps Defaults to 0.
            
        """
        return self.submit_job("/predictions", task=task, input_file=input_file, fps=fps, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class hidream_l1_fast(FastClient):
    """
    Generated client for prunaai/hidream-l1-fast
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="813450de-15b9-40b8-8a04-3cbcfde87b02", api_key=api_key)
    
    def predictions(self, prompt: str, seed: int = -1, model_type: str = 'fast', resolution: str = '1024 × 1024 (Square)', speed_mode: str = 'Lightly Juiced 🍊 (more consistent)', output_format: str = 'webp', output_quality: int = 100, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            prompt: Prompt
            
            seed: Random seed (-1 for random) Defaults to -1.
            
            model_type: Model type Defaults to 'fast'.
            
            resolution: Output resolution Defaults to '1024 × 1024 (Square)'.
            
            speed_mode: Speed optimization level Defaults to 'Lightly Juiced 🍊 (more consistent)'.
            
            output_format: Output format Defaults to 'webp'.
            
            output_quality: Output quality (for jpg and webp) Defaults to 100.
            
        """
        return self.submit_job("/predictions", prompt=prompt, seed=seed, model_type=model_type, resolution=resolution, speed_mode=speed_mode, output_format=output_format, output_quality=output_quality, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class stable_diffusion_dance(FastClient):
    """
    Generated client for pollinations/stable-diffusion-dance
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="35430f6b-5b5a-45c2-adf9-6830a2f707ac", api_key=api_key)
    
    def predictions(self, width: int = 384, height: int = 512, prompts: str = 'a moth\na killer dragonfly\nTwo fishes talking to eachother in deep sea', batch_size: int = 24, frame_rate: float = 16.0, random_seed: int = 13, prompt_scale: float = 15.0, style_suffix: str = 'Painting by Paul Klee, intricate details', audio_smoothing: float = 0.8, diffusion_steps: int = 20, audio_noise_scale: float = 0.3, audio_loudness_type: str = 'peak', frame_interpolation: bool = True, audio_file: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            width: Width of the generated image. The model was really only trained on 512x512 images. Other sizes tend to create less coherent images. Defaults to 384.
            
            height: Height of the generated image. The model was really only trained on 512x512 images. Other sizes tend to create less coherent images. Defaults to 512.
            
            prompts: prompts Defaults to 'a moth\na killer dragonfly\nTwo fishes talking to eachother in deep sea'.
            
            batch_size: Number of images to generate at once. Higher batch sizes will generate images faster but will use more GPU memory i.e. not work depending on resolution. Defaults to 24.
            
            frame_rate: Frames per second for the generated video. Defaults to 16.0.
            
            random_seed: Each seed generates a different image Defaults to 13.
            
            prompt_scale: Determines influence of your prompt on generation. Defaults to 15.0.
            
            style_suffix: Style suffix to add to the prompt. This can be used to add the same style to each prompt. Defaults to 'Painting by Paul Klee, intricate details'.
            
            audio_smoothing: Audio smoothing factor. Defaults to 0.8.
            
            diffusion_steps: Number of diffusion steps. Higher steps could produce better results but will take longer to generate. Maximum 30 (using K-Euler-Diffusion). Defaults to 20.
            
            audio_noise_scale: Larger values mean audio will lead to bigger changes in the image. Defaults to 0.3.
            
            audio_loudness_type: Type of loudness to use for audio. Options are 'rms' or 'peak'. Defaults to 'peak'.
            
            frame_interpolation: Whether to interpolate between frames using FFMPEG or not. Defaults to True.
            
            audio_file: input audio file Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompts=prompts, batch_size=batch_size, frame_rate=frame_rate, random_seed=random_seed, prompt_scale=prompt_scale, style_suffix=style_suffix, audio_smoothing=audio_smoothing, diffusion_steps=diffusion_steps, audio_noise_scale=audio_noise_scale, audio_loudness_type=audio_loudness_type, frame_interpolation=frame_interpolation, audio_file=audio_file, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class edit_video_by_editing_text(FastClient):
    """
    Generated client for jd7h/edit-video-by-editing-text
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="ed6f5d3e-761f-4f00-b342-1f7e55301c87", api_key=api_key)
    
    def predictions(self, video_in: Union[MediaFile, str, bytes], mode: str = 'transcribe', split_at: str = 'word', transcription: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video_in: Video file to transcribe or edit
            
            mode: Mode: either transcribe or edit Defaults to 'transcribe'.
            
            split_at: When using mode 'edit', split transcription at the word level or character level. Default: word level. Character level is more precise but can lead to matching errors. Defaults to 'word'.
            
            transcription: When using mode 'edit', this should be the transcription of the desired output video. Use mode 'transcribe' to create a starting point. Optional.
            
        """
        return self.submit_job("/predictions", video_in=video_in, mode=mode, split_at=split_at, transcription=transcription, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.bytedance.hyper_flux_16step import hyper_flux_16step
from socaity.sdk.replicate.bytedance.hyper_flux_8step import hyper_flux_8step
from socaity.sdk.replicate.bytedance.sdxl_lightning_4step import sdxl_lightning_4step


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class realistic_voice_cloning(FastClient):
    """
    Generated client for zsxkib/realistic-voice-cloning
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="618b07ed-2cab-4ab9-9c79-ba83724ea423", api_key=api_key)
    
    def predictions(self, protect: float = 0.33, rvc_model: str = 'Squidward', index_rate: float = 0.5, reverb_size: float = 0.15, pitch_change: str = 'no-change', rms_mix_rate: float = 0.25, filter_radius: int = 3, output_format: str = 'mp3', reverb_damping: float = 0.7, reverb_dryness: float = 0.8, reverb_wetness: float = 0.2, crepe_hop_length: int = 128, pitch_change_all: float = 0.0, main_vocals_volume_change: float = 0.0, pitch_detection_algorithm: str = 'rmvpe', instrumental_volume_change: float = 0.0, backup_vocals_volume_change: float = 0.0, song_input: Optional[Union[MediaFile, str, bytes]] = None, custom_rvc_model_download_url: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            protect: Control how much of the original vocals' breath and voiceless consonants to leave in the AI vocals. Set 0.5 to disable. Defaults to 0.33.
            
            rvc_model: RVC model for a specific voice. If using a custom model, this should match the name of the downloaded model. If a 'custom_rvc_model_download_url' is provided, this will be automatically set to the name of the downloaded model. Defaults to 'Squidward'.
            
            index_rate: Control how much of the AI's accent to leave in the vocals. Defaults to 0.5.
            
            reverb_size: The larger the room, the longer the reverb time. Defaults to 0.15.
            
            pitch_change: Adjust pitch of AI vocals. Options: `no-change`, `male-to-female`, `female-to-male`. Defaults to 'no-change'.
            
            rms_mix_rate: Control how much to use the original vocal's loudness (0) or a fixed loudness (1). Defaults to 0.25.
            
            filter_radius: If >=3: apply median filtering median filtering to the harvested pitch results. Defaults to 3.
            
            output_format: wav for best quality and large file size, mp3 for decent quality and small file size. Defaults to 'mp3'.
            
            reverb_damping: Absorption of high frequencies in the reverb. Defaults to 0.7.
            
            reverb_dryness: Level of AI vocals without reverb. Defaults to 0.8.
            
            reverb_wetness: Level of AI vocals with reverb. Defaults to 0.2.
            
            crepe_hop_length: When `pitch_detection_algo` is set to `mangio-crepe`, this controls how often it checks for pitch changes in milliseconds. Lower values lead to longer conversions and higher risk of voice cracks, but better pitch accuracy. Defaults to 128.
            
            pitch_change_all: Change pitch/key of background music, backup vocals and AI vocals in semitones. Reduces sound quality slightly. Defaults to 0.0.
            
            main_vocals_volume_change: Control volume of main AI vocals. Use -3 to decrease the volume by 3 decibels, or 3 to increase the volume by 3 decibels. Defaults to 0.0.
            
            pitch_detection_algorithm: Best option is rmvpe (clarity in vocals), then mangio-crepe (smoother vocals). Defaults to 'rmvpe'.
            
            instrumental_volume_change: Control volume of the background music/instrumentals. Defaults to 0.0.
            
            backup_vocals_volume_change: Control volume of backup AI vocals. Defaults to 0.0.
            
            song_input: Upload your audio file here. Optional.
            
            custom_rvc_model_download_url: URL to download a custom RVC model. If provided, the model will be downloaded (if it doesn't already exist) and used for prediction, regardless of the 'rvc_model' value. Optional.
            
        """
        return self.submit_job("/predictions", protect=protect, rvc_model=rvc_model, index_rate=index_rate, reverb_size=reverb_size, pitch_change=pitch_change, rms_mix_rate=rms_mix_rate, filter_radius=filter_radius, output_format=output_format, reverb_damping=reverb_damping, reverb_dryness=reverb_dryness, reverb_wetness=reverb_wetness, crepe_hop_length=crepe_hop_length, pitch_change_all=pitch_change_all, main_vocals_volume_change=main_vocals_volume_change, pitch_detection_algorithm=pitch_detection_algorithm, instrumental_volume_change=instrumental_volume_change, backup_vocals_volume_change=backup_vocals_volume_change, song_input=song_input, custom_rvc_model_download_url=custom_rvc_model_download_url, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.fofr._0_1_webp import _0_1_webp
from socaity.sdk.replicate.fofr.any_comfyui_workflow import any_comfyui_workflow
from socaity.sdk.replicate.fofr.audio_to_waveform import audio_to_waveform
from socaity.sdk.replicate.fofr.aura_flow import aura_flow
from socaity.sdk.replicate.fofr.controlnet_preprocessors import controlnet_preprocessors
from socaity.sdk.replicate.fofr.flux_2004 import flux_2004
from socaity.sdk.replicate.fofr.flux_80s_cyberpunk import flux_80s_cyberpunk
from socaity.sdk.replicate.fofr.flux_bad_70s_food import flux_bad_70s_food
from socaity.sdk.replicate.fofr.flux_beyond_horizon import flux_beyond_horizon
from socaity.sdk.replicate.fofr.flux_black_light import flux_black_light
from socaity.sdk.replicate.fofr.flux_brighton_west_pier import flux_brighton_west_pier
from socaity.sdk.replicate.fofr.flux_cassette_futurism import flux_cassette_futurism
from socaity.sdk.replicate.fofr.flux_color import flux_color
from socaity.sdk.replicate.fofr.flux_cross_section import flux_cross_section
from socaity.sdk.replicate.fofr.flux_cyberpunk_typeface import flux_cyberpunk_typeface
from socaity.sdk.replicate.fofr.flux_hyundai_n_vision_74 import flux_hyundai_n_vision_74
from socaity.sdk.replicate.fofr.flux_jwst import flux_jwst
from socaity.sdk.replicate.fofr.flux_macro_texture import flux_macro_texture
from socaity.sdk.replicate.fofr.flux_minecraft_movie import flux_minecraft_movie
from socaity.sdk.replicate.fofr.flux_mjv3 import flux_mjv3
from socaity.sdk.replicate.fofr.flux_mona_lisa import flux_mona_lisa
from socaity.sdk.replicate.fofr.flux_myst import flux_myst
from socaity.sdk.replicate.fofr.flux_neo_1x import flux_neo_1x
from socaity.sdk.replicate.fofr.flux_pixar_cars import flux_pixar_cars
from socaity.sdk.replicate.fofr.flux_spitting_image import flux_spitting_image
from socaity.sdk.replicate.fofr.flux_tessellate import flux_tessellate
from socaity.sdk.replicate.fofr.flux_wrong import flux_wrong
from socaity.sdk.replicate.fofr.flux_y2k import flux_y2k
from socaity.sdk.replicate.fofr.frames_to_video import frames_to_video
from socaity.sdk.replicate.fofr.latent_consistency_model import latent_consistency_model
from socaity.sdk.replicate.fofr.musicgen_choral import musicgen_choral
from socaity.sdk.replicate.fofr.realvisxl_v3_multi_controlnet_lora import realvisxl_v3_multi_controlnet_lora
from socaity.sdk.replicate.fofr.sdxl_emoji import sdxl_emoji
from socaity.sdk.replicate.fofr.sdxl_multi_controlnet_lora import sdxl_multi_controlnet_lora
from socaity.sdk.replicate.fofr.sticker_maker import sticker_maker
from socaity.sdk.replicate.fofr.toolkit import toolkit
from socaity.sdk.replicate.fofr.tooncrafter import tooncrafter
from socaity.sdk.replicate.fofr.video_morpher import video_morpher
from socaity.sdk.replicate.fofr.video_to_frames import video_to_frames
from socaity.sdk.replicate.fofr.wan2_1_with_lora import wan2_1_with_lora


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class lgm(FastClient):
    """
    Generated client for camenduru/lgm
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="576eb7a3-8357-412d-be64-4f7f531bb198", api_key=api_key)
    
    def predictions(self, input_image: Union[MediaFile, str, bytes], seed: int = 42, prompt: str = 'a songbird', negative_prompt: str = 'ugly, blurry, pixelated obscure, unnatural colors, poor lighting, dull, unclear, cropped, lowres, low quality, artifacts, duplicate', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            input_image: Input Image
            
            seed: seed Defaults to 42.
            
            prompt: prompt Defaults to 'a songbird'.
            
            negative_prompt: negative_prompt Defaults to 'ugly, blurry, pixelated obscure, unnatural colors, poor lighting, dull, unclear, cropped, lowres, low quality, artifacts, duplicate'.
            
        """
        return self.submit_job("/predictions", input_image=input_image, seed=seed, prompt=prompt, negative_prompt=negative_prompt, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.sdk.replicate.fermatresearch.dpo_sdxl_controlnet_lora import dpo_sdxl_controlnet_lora
from socaity.sdk.replicate.fermatresearch.high_resolution_controlnet_tile import high_resolution_controlnet_tile
from socaity.sdk.replicate.fermatresearch.magic_image_refiner import magic_image_refiner
from socaity.sdk.replicate.fermatresearch.sdxl_controlnet_lora import sdxl_controlnet_lora
from socaity.sdk.replicate.fermatresearch.spanish_f5_tts import spanish_f5_tts


from fastsdk import FastClient, APISeex
from typing import Union

from media_toolkit import MediaFile


class mediapipe_face(FastClient):
    """
    Generated client for chigozienri/mediapipe-face
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f5adba97-df80-4165-94ec-0014501d1719", api_key=api_key)
    
    def predictions(self, images: Union[MediaFile, str, bytes], bias: float = 0.0, blur_amount: float = 0.0, output_transparent_image: bool = False, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            images: Input image as png or jpeg, or zip/tar of input images
            
            bias: Bias to apply to mask (lightens background) Defaults to 0.0.
            
            blur_amount: Blur to apply to mask Defaults to 0.0.
            
            output_transparent_image: if true, outputs face image with transparent background Defaults to False.
            
        """
        return self.submit_job("/predictions", images=images, bias=bias, blur_amount=blur_amount, output_transparent_image=output_transparent_image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class gpt_j_6b(FastClient):
    """
    Generated client for replicate/gpt-j-6b
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="7bc71c35-504b-473a-bd3d-e62f0d526bf8", api_key=api_key)
    
    def predictions(self, prompt: str, top_k: int = 50, top_p: float = 1.0, decoding: str = 'top_p', max_length: int = 500, temperature: float = 0.75, repetition_penalty: float = 1.2, **kwargs) -> APISeex:
        """
        Run a single prediction on the model
        
        
        Args:
            prompt: Input Prompt.
            
            top_k: Valid if you choose top_k decoding. The number of highest probability vocabulary tokens to keep for top-k-filtering Defaults to 50.
            
            top_p: Valid if you choose top_p decoding. When decoding text, samples from the top p percentage of most likely tokens; lower to ignore less likely tokens Defaults to 1.0.
            
            decoding: Choose a decoding method Defaults to 'top_p'.
            
            max_length: Maximum number of tokens to generate. A word is generally 2-3 tokens Defaults to 500.
            
            temperature: Adjusts randomness of outputs, greater than 1 is random and 0 is deterministic, 0.75 is a good starting value. Defaults to 0.75.
            
            repetition_penalty: Penalty for repeated words in generated text; 1 is no penalty, values greater than 1 discourage repetition, less than 1 encourage it. Defaults to 1.2.
            
        """
        return self.submit_job("/predictions", prompt=prompt, top_k=top_k, top_p=top_p, decoding=decoding, max_length=max_length, temperature=temperature, repetition_penalty=repetition_penalty, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class controlvideo(FastClient):
    """
    Generated client for cjwbw/controlvideo
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="f9e98013-d3c4-40d5-b37f-09d47e02127e", api_key=api_key)
    
    def predictions(self, video_path: Union[MediaFile, str, bytes], prompt: str = 'A striking mallard floats effortlessly on the sparkling pond.', condition: str = 'depth', video_length: int = 15, is_long_video: bool = False, guidance_scale: float = 12.5, smoother_steps: str = '19, 20', num_inference_steps: int = 50, seed: Optional[str] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            video_path: source video
            
            prompt: Text description of target video Defaults to 'A striking mallard floats effortlessly on the sparkling pond.'.
            
            condition: Condition of structure sequence Defaults to 'depth'.
            
            video_length: Length of synthesized video Defaults to 15.
            
            is_long_video: Whether to use hierarchical sampler to produce long video Defaults to False.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 12.5.
            
            smoother_steps: Timesteps at which using interleaved-frame smoother, separate with comma Defaults to '19, 20'.
            
            num_inference_steps: Number of denoising steps Defaults to 50.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
        """
        return self.submit_job("/predictions", video_path=video_path, prompt=prompt, condition=condition, video_length=video_length, is_long_video=is_long_video, guidance_scale=guidance_scale, smoother_steps=smoother_steps, num_inference_steps=num_inference_steps, seed=seed, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class nomic_embed_text_v1(FastClient):
    """
    Generated client for lucataco/nomic-embed-text-v1
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="98467a14-427e-4efb-8ffb-4a10cc89a4fc", api_key=api_key)
    
    def predictions(self, sentences: str, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            sentences: Input Sentence list - Each sentence should be split by a newline
            
        """
        return self.submit_job("/predictions", sentences=sentences, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex

class emopia(FastClient):
    """
    Generated client for annahung31/emopia
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="0c8acf67-d668-45ed-b08a-fafcdb97aa57", api_key=api_key)
    
    def predictions(self, seed: int = -1, emotion: str = 'High valence, high arousal', **kwargs) -> APISeex:
        """
        
        
        
        Args:
            seed: Random seed, -1 for random Defaults to -1.
            
            emotion: Emotion to generate for Defaults to 'High valence, high arousal'.
            
        """
        return self.submit_job("/predictions", seed=seed, emotion=emotion, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from fastsdk import FastClient, APISeex
from typing import Union, Optional

from media_toolkit import MediaFile


class playground_v2_5_1024px_aesthetic(FastClient):
    """
    Generated client for playgroundai/playground-v2-5-1024px-aesthetic
    """
    def __init__(self, api_key: str = None):
        super().__init__(service_name_or_id="98466e47-f0f6-4cfe-8842-f7758bd9d61c", api_key=api_key)
    
    def predictions(self, width: int = 1024, height: int = 1024, prompt: str = 'Astronaut in a jungle, cold color palette, muted colors, detailed, 8k', scheduler: str = 'DPMSolver++', num_outputs: int = 1, guidance_scale: float = 3.0, apply_watermark: bool = True, negative_prompt: str = 'ugly, deformed, noisy, blurry, distorted', prompt_strength: float = 0.8, num_inference_steps: int = 25, disable_safety_checker: bool = False, mask: Optional[Union[MediaFile, str, bytes]] = None, seed: Optional[int] = None, image: Optional[Union[MediaFile, str, bytes]] = None, **kwargs) -> APISeex:
        """
        
        
        
        Args:
            width: Width of output image Defaults to 1024.
            
            height: Height of output image Defaults to 1024.
            
            prompt: Input prompt Defaults to 'Astronaut in a jungle, cold color palette, muted colors, detailed, 8k'.
            
            scheduler: Scheduler. DPMSolver++ or DPM++2MKarras is recommended for most cases Defaults to 'DPMSolver++'.
            
            num_outputs: Number of images to output. Defaults to 1.
            
            guidance_scale: Scale for classifier-free guidance Defaults to 3.0.
            
            apply_watermark: Applies a watermark to enable determining if an image is generated in downstream applications. If you have other provisions for generating or deploying images safely, you can use this to disable watermarking. Defaults to True.
            
            negative_prompt: Negative Input prompt Defaults to 'ugly, deformed, noisy, blurry, distorted'.
            
            prompt_strength: Prompt strength when using img2img / inpaint. 1.0 corresponds to full destruction of information in image Defaults to 0.8.
            
            num_inference_steps: Number of denoising steps Defaults to 25.
            
            disable_safety_checker: Disable safety checker for generated images. This feature is only available through the API. See https://replicate.com/docs/how-does-replicate-work#safety Defaults to False.
            
            mask: Input mask for inpaint mode. Black areas will be preserved, white areas will be inpainted. Optional.
            
            seed: Random seed. Leave blank to randomize the seed Optional.
            
            image: Input image for img2img or inpaint mode Optional.
            
        """
        return self.submit_job("/predictions", width=width, height=height, prompt=prompt, scheduler=scheduler, num_outputs=num_outputs, guidance_scale=guidance_scale, apply_watermark=apply_watermark, negative_prompt=negative_prompt, prompt_strength=prompt_strength, num_inference_steps=num_inference_steps, disable_safety_checker=disable_safety_checker, mask=mask, seed=seed, image=image, **kwargs)
    
    # Convenience aliases for the primary endpoint
    run = predictions
    __call__ = predictions


from socaity.core.socaity_service_manager import SocaityServiceManager

from media_toolkit import MediaFile, ImageFile, VideoFile, AudioFile

# from socaity.sdk import official, community, replicate
# from socaity.sdk.official import *

from fastsdk import FastSDK
service_manager = FastSDK().service_manager = SocaityServiceManager()
